/*
Theme Name: SpicePress
Theme URI: https://spicethemes.com/spicepress-wordpress-theme/
Author: spicethemes
Author URI: https://spicethemes.com
Description: SpicePress is a responsive, modern, and highly customizable WordPress business theme built to create professional websites with ease. It is suitable for corporate websites, creative agencies, startups, freelancers, restaurants, wedding planners, law firms, consulting firms, travel agencies, photography portfolios, blogs, and WooCommerce-powered online stores.The theme includes ready-to-use starter sites, allowing you to import professionally designed demo layouts and launch your website within minutes. These starter sites can be previewed and imported directly from a dedicated starter site panel, making the setup process fast and beginner-friendly.SpicePress offers a powerful yet easy-to-use customization experience through the WordPress Customizer, enabling you to control layouts, colors, typography, and content without writing any code. The theme is translation-ready and fully compatible with popular plugins such as WooCommerce, WPML, Polylang, and Contact Form 7, making it suitable for multilingual and business-focused websites.SpicePress is GDPR-compliant and does not rely on external Google Fonts. All fonts are hosted locally to ensure improved performance, better privacy, and compliance with modern web standards.
Tags: one-column, two-columns, right-sidebar, custom-menu, custom-logo, editor-style, featured-images, footer-widgets, sticky-post, threaded-comments, translation-ready, rtl-language-support, e-commerce
Version: 2.3.2.5
Requires at least: 4.5
Tested up to: 6.9
Requires PHP: 5.4
License URI: http://www.gnu.org/licenses/gpl-2.0.html
License: GNU General Public License v2 or later
Text Domain: spicepress
*/

html {
	overflow-y: scroll;
	overflow-x: hidden;
	-ms-overflow-style: scrollbar;
}

html { font-size: 14px; }
@media(min-width:60em) { html { font-size: 16px; } }

body {
	background: #f5f5f5;
	color: #64646d;
	font-family: "Open Sans", Helvetica, Arial, sans-serif;
	font-size: 0.9375rem; /*=15px*/
	line-height: 1.6;
	font-weight: 400;
	padding: 0;
	background-attachment: fixed;
	text-rendering: optimizeLegibility;
	overflow-x: hidden;
}
h1, .h1 { font-size: 2rem; }       /* =32px */
h2, .h2 { font-size: 1.875rem; }   /* =30px */
h3, .h3 { font-size: 1.5rem; }     /* =24px */
h4, .h4 { font-size: 1.25rem; }    /* =20px */
h5, .h5 { font-size: 1.125rem; }   /* =18px */
h6, .h6 { font-size: 1rem; }       /* =16px */
h1, .h1, h2, .h2, h3, .h3,
h4, .h4, h5, .h5, h6, .h6 { color: #0f0f16; margin: 0px 0 20px; font-weight: 600; word-wrap: break-word; }
p { margin: 20px 0 0px; color: #64646d; }
p:first-child { margin-top: 0px; }
img { max-width: 100%; display: block; height: auto; }
#wrapper {
	background: #f5f5f5;
	box-shadow: 0 0 5px 0 rgba(0, 0, 0, 0.5);
	margin: 0 auto;
	position: relative;
	transition: all 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94) 0s;
}
.p-l-r-0 { padding-right: 0px; padding-left: 0px; }
.site-title a { color: #333}
.site-description {color: #5f5555}

/*===================================================================================*/
/*	HOMEPAGE  SECTION
/*===================================================================================*/

.slider .overlay {
    content:"";
    display: block;
    height: 100%;
    position: absolute;
    top: 0;
    right: 0;
    width: 100%;
    z-index: 0;
}

.page-seperate { background: url("images/page-shadow.png") no-repeat center bottom; padding-bottom: 70px; margin: 0px; }


/*Standard Format*/
.slider .format-standard {
	height: auto;
	margin: 0;
	padding: 0;
	position: absolute;
	width: 50%;
	z-index: 1;
	top: 50%;
	-webkit-transform: translateY(-50%);
	-ms-transform: translateY(-50%);
	transform: translateY(-50%);
}
.slide-text-bg1 {
    background-color: rgba(18, 4, 1, 0.8);
    float: right;
    text-align: right;
    margin: 0px;
    padding: 17px 20px 20px 20px;
    position: relative;
    width: 70%;
    z-index: 773;
}
.slide-text-bg1 h1 {
	color: #ffffff;
	text-shadow: 0 0px 1px rgba(155, 155, 155, 0.7);
	border-radius: 2px;
	padding: 0 0 10px;
	display: inline-block;
	letter-spacing: 0;
	margin: 0px;
}
.slide-text-bg1 p {
	color: #ffffff;
	text-shadow: 0 0px 1px rgba(155, 155, 155, 0.7);
	font-size: 1.063rem;
	font-weight: 400;
	display: inline-block;
	border-radius: 2px;
	padding: 0;
	margin: 0 0 0px;
}
.slide-btn-area-sm { margin: 0px 0 0px; float: right; width: 80%; }
.slide-btn-sm {
    min-width: 11rem;
    display: inline-block;
    font-family: "Montserrat", "Trebuchet MS", Helvetica, sans-serif;
    -webkit-font-smoothing: antialiased;
    position: relative;
	font-size: 0.875rem;
	letter-spacing: 0.083rem;
    padding: .8rem 1.4rem;
    padding-left: 4.7rem;
    background: #191919;
	text-align: center;
    border: none;
    color: #fff;
    transition: .2s;
}
.slide-btn-sm:hover, .slide-btn-sm:focus { color: #fff; }
.slide-btn-sm:before { background: rgba(0, 0, 0, 0.1); }
.slide-btn-sm:before, .slide-btn-sm:after {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    padding-top: inherit;
    padding-bottom: inherit;
    width: 2.8rem;
    content: "\00a0";
    font-family: 'FontAwesome', sans-serif;
    text-align: center;
    transition: .2s;
    transform-origin: 50% 60%;
}
.slide-btn-sm:after { content: "\F053"; }
@media (max-width: 380px) {
.slide-btn-sm { min-width: 13rem; }
}


.format-status-btn-sm {
	color: #ffffff;
	border-radius: 2px;
    cursor: pointer;
    display: inline-block;
	transition: all 0.3s ease-in-out 0s;
	font-size: 	0.813rem;
    font-weight: 600;
    padding: 6px 11px;
	margin: 15px 0 15px;
    text-align: center;
    text-transform: uppercase;
    vertical-align: middle;
}
.format-status-btn-sm:hover { color: #ffffff; }

.format-video-btn-sm {
	color: #ffffff;
	border-radius: 2px;
    cursor: pointer;
    display: inline-block;
	transition: all 0.3s ease-in-out 0s;
	font-size: 0.813rem;
    font-weight: 600;
    padding: 6px 15px;
	margin: 15px 0 15px;
    text-align: center;
    text-transform: uppercase;
    vertical-align: middle;
}
.format-video-btn-sm:hover { color: #ffffff; }


.slide-shadow { padding-bottom: 21px; margin: 0 0 60px; }



/*===================================================================================*/
/*	SECTION HEADER CSS
/*===================================================================================*/

.section-header {
    background-position: center top;
    background-repeat: no-repeat;
    margin: -15px auto 45px;
    padding: 0;
    position: relative;
    text-align: center;
}
.section-header h1.widget-title { margin: 0px; color: #0f0f16; }
.section-header p { margin: 0px; font-size: 1.000rem; }
.widget-separator { background-color: #cccccc; width: 180px; height: 1px; margin: 15px auto 21px; }
.widget-separator span { width: 30px; height: 4px; margin: 0px auto; display: block; position: relative; bottom: 2px; }
.white { color: #ffffff !important; }

/*===================================================================================*/
/*	SERVICE SECTION
/*===================================================================================*/

.page-template-template-service #wrapper { background: #fff; }
.service-padding { padding-top: 0 !important; }
.service-section { background-color: #ffffff; border-bottom: 1px solid #e8e8e8; padding: 70px 0 30px; }
.service-section .post { background-color: #f9f9f9; border: 1px solid #e9e9e9; border-top: 3px solid #e9e9e9; margin: 0 0 40px; padding: 25px 20px 30px; transition: 0.3s; }
.service-section .post:hover { box-shadow: 0 30px 30px 0 rgba(0,0,0,0.1); }
.service-section .post .post-thumbnail {
	margin: 0 0 15px;
	width: 100%;
	overflow: hidden;
	position: relative;
	-webkit-transform: perspective(1px) translateZ(0);
    transform: perspective(1px) translateZ(0);
    position: relative;
    -webkit-transition-duration: 0.2s;
    transition-duration: 0.2s;
}
.service-section .post:hover .post-thumbnail { -webkit-transform: translateY(-5px); transform: translateY(-5px); }
.service-section .post .post-thumbnail i.fa { font-size: 4.286rem; line-height: 105%; padding: 0px; position: relative; }
.service-section .post .entry-header { display: block; margin: 0 0 15px; padding: 0; }
.service-section .entry-header .entry-title  { margin: 0; font-weight: 700; }
.service-section .entry-header .entry-title:after {
    content: '';
	background-color: #e9e9e9;
    font-size: 1rem;
    height: 2px;
    width: 5.5rem;
    display: block;
    margin: 0.8rem auto 0rem;
}
.txt-green { color: #6dc82b; }
.txt-orange { color: #fe8000; }
.txt-blue { color: #1abac8; }
.more-link { margin: 15px 0 0; display: block; font-weight: 600; }

/*===================================================================================*/
/*	HOMEPAGE PORTFOLIO SECTION
/*===================================================================================*/

.portfolio-section { background: transparent; margin: 0px; padding: 60px 0 30px; width: 100%; }
.portfolio-section .post { background-color: #ffffff; border: 1px solid #e9e9e9;border-radius: 0; margin-bottom: 40px; padding: 15px; transition: all 0.4s ease 0s; }
.padding-0 { padding-top: 0 !important; }
.portfolio-section .post-thumbnail {
    margin: 0px 0 16px;
    width: 100%;
	overflow: hidden;
	position: relative;
	transition: all 200ms ease-out 0s;
}
.portfolio-section .post-thumbnail img { transition: all 300ms ease-out 0s; width: 100%; opacity: 1; }
.portfolio-section .post .post-thumbnail:hover img {
	-webkit-transform: scale(1.15);/* Saf3.1+, Chrome */
	-moz-transform: scale(1.15); /* FF3.5+ */
	-ms-transform: scale(1.15); /* IE9 */
	-o-transform: scale(1.15); /* Opera 10.5+ */
	transform: scale(1.15);
	opacity: 1;
}
.portfolio-section .entry-header .entry-title { font-weight: 700; margin: 0 0 5px; }
/*Porttfolio Lightbox*/
.thumbnail-showcase-overlay {
	background: rgba(0, 0, 0, 0.7);
	visibility: hidden;
	opacity: 0;
	transition: all 0.4s ease;
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	width: 100%;
	height: 100%;
	border-radius: 0;
	padding: 1.42857rem;
}
.portfolio-section .post .post-thumbnail:hover .thumbnail-showcase-overlay { visibility: visible; opacity: 1; height: 100%; }
.portfolio-section .post .post-thumbnail{
	text-align:center;
	position:relative;
	line-height:0px;
	font-size:0px;
	transition: all 200ms ease-out;
	-webkit-transition: all 200ms ease-out;
	width:100%;
	position:relative;
	height:100%;
	overflow:hidden;
}
.portfolio-section .post .post-thumbnail .thumbnail-showcase-icons { margin: -20px 0 0; position: absolute; top: 50%; left: 0; width: 100%; }
.portfolio-section .post .post-thumbnail .thumbnail-showcase-icons a {
    font-size: 1.250rem;
	line-height: 2.1;
    display: inline-block;
    margin: 0 10px 0 0;
    padding: 1px;
    opacity: 1;
	text-decoration: none;
	text-align: center;
	color: #0f0f16;
	width: 2.85714rem;
	height: 2.85714rem;
	border-radius: 50%;
	background-color: #fff;
    -wekbit-transition: all 0.4s;
    -moz-transition: all 0.4s;
    -o-transition: all 0.4s;
    transition: all 0.4s;
    -wekbit-transform: translateY(30px);
    -moz-transform: translateY(30px);
    -o-transform: translateY(30px);
    -ms-transform: translateY(30px);
    transform: translateY(30px);
}
.portfolio-section .post .post-thumbnail:hover .thumbnail-showcase-icons a {
    -wekbit-transform: translateY(0);
    -moz-transform: translateY(0);
    -o-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
}
.portfolio-section .post .post-thumbnail .thumbnail-showcase-icons a:hover { opacity: 1; }

/*===================================================================================*/
/*	TESTIMONIAL SECTION
/*===================================================================================*/

.testimonial-section {
	background: url("images/testimonial-bg.jpg");

	background-position: center !important;
    background-repeat: no-repeat !important;
    background-size: cover !important;



	background-attachment: fixed !important;
	height: 100%;
	margin: 0;
	overflow: hidden;
	padding: 0;
	width: 100%;
}
.testimonial-section .overlay { height: 100%; padding: 70px 0 55px; position: relative; width: 100%; }
.testmonial-area { margin: 0px 0 30px; padding: 0 50px 0 50px; }
.description-box { background-color: #ffffff; border-radius: 0px; margin: 0 0 35px; padding: 30px; position: relative; min-height: 145px; }
.description-box:before {
	left: 0;
	right: 30px;
	bottom: -15px;
	width: 0;
	height: 0;
	content: "";
	position: absolute;
	display: block;
	border-right: 14px solid transparent;
	border-left: 14px solid transparent;
	border-top: 15px solid #ffffff;
}

.author-description { display: block; margin-bottom: 0px; margin-top: 0; }
.author-description p { font-weight: 500; font-size: 1.125rem; }
.author-description p:before { content: '\f10e'; font-family: FontAwesome; font-size: 1.500rem; line-height: 0.1em; margin-left: 0.50em;    vertical-align: -0.1em; position: relative; top: 0px; float: right; }
.testmonial-area h4 { color: #ffffff; font-weight: 600; font-size: 1.000rem; margin-bottom: 5px; letter-spacing: 1px; display: block; margin-top: 0; }
.testmonial-area span { padding: 0 4px 0 0; }
.testmonial-area .media-body { margin: 13px 0 0; }
.author-box { float: right; margin: 0 0 20px 35px; width: 100px; height: auto;  }
.author-box img { background-color: transparent; border: 1px solid #ffffff; padding: 4px; max-width: 100%; }
.text-color { color: #ffffff !important; }

/*===================================================================================*/
/*	WIDGET TITLE CSS
/*===================================================================================*/

.widget { margin: 0; padding: 60px 0; }
.widget-title { color: #0f0f16; margin: 0 0 25px; }
a:hover, a:focus { text-decoration: none !important; }


/*===================================================================================*/
/*	ABOUT PAGE CALLOUT
/*===================================================================================*/

.about-callout-section { padding: 70px 0 40px; }

/*===================================================================================*/
/*	PAGE TITLE SECTION
/*===================================================================================*/

.page-title-section { height: 100%; margin: 0 0 0px; overflow: hidden; position: relative; padding: 0; width: 100%; }
.page-title-section .overlay { height: 100%; padding: 50px 0 48px; position: relative; width: 100%; }
.page-title {
	background-position: center top;
	background-repeat: no-repeat;
	margin: 0 auto 0px;
	padding: 0px;
	position: relative;
	width: 99%;
}
.page-title h1 { color: #ffffff; letter-spacing: 1px; margin: 0px; word-wrap: break-word; float: left; }
.page-breadcrumb {
	list-style: none outside none;
	margin: 0px;
	padding: 15px 0 0;
	font-weight: 500;
	text-align: left;
	line-height: 1.000rem;
        float: right;
}
.page-breadcrumb > li { display: inline-block; }
.page-breadcrumb > li + li:before { color: #ffffff; content: "/ "; padding: 0 5px; }
.page-breadcrumb > li a, .page-breadcrumb > li.active a { color: #ffffff; }
.page-seperator { height: 70px; width: 100%; overflow: hidden;}
.margin-top { margin-top: 0px; } .margin-bottom { margin-bottom: 0px; }
.woocommerce .woocommerce-breadcrumb a, .woocommerce .woocommerce-breadcrumb{
	color:#ffffff;
	font-size: 0.9375rem;
}

@media (min-width: 200px) and (max-width: 990px) {
	.page-title-section .overlay { padding: 25px 0 30px; }
}
@media only screen and (min-width: 200px) and (max-width: 767px) {
	.page-title h1 { text-align: center; }
	.page-breadcrumb { text-align: center; padding: 15px 0 5px; }
}

/*===================================================================================*/
/*	ABOUT US PAGE SECTION
/*===================================================================================*/

.about-section { background-color: #f4f4f4; margin: 0px; padding: 0 0 70px; overflow: hidden; width: 100%; }
.about-img-area { margin: 0; padding: 1px; position: relative; }
.about-img-area img { border-radius: 0px; border: 5px solid #fff;
	-moz-box-shadow: 0px 0px 2px #ccc;
	-webkit-box-shadow: 0px 0px 2px #ccc;
	box-shadow: 0px 0px 2px #ccc; }
.about-section h2 { color: #0f0f16; margin-bottom: 25px; margin-top: 0; padding: 0px; }
.about-section p {
	margin: 0 0 15px;
	padding: 0px;
}
.about-social { float: right; margin: 0px 0px 0px 0px; padding: 5px 0; }
.about-social li {
	background-color: #ffffff;
	border: 1px solid #e3e3e3;
	border-radius: 0;
	cursor: pointer;
	display: inline-block;
	-webkit-border-radius: 2px;
	-moz-border-radius: 2px;
	border-radius: 2px;
	height: 35px;
	margin-bottom: 0px;
	margin-left: 0px;
	margin-top: 0px;
	padding: 0px;
	text-align: center;
	transition: background 0.2s ease-in-out 0s;
	width: 35px;
}
.about-social li.facebook:hover { background-color: #4c66a4; }
.about-social li.twitter:hover { background-color: #15b4c9; }
.about-social li.linkedin:hover { background-color: #006599; }
.about-social li.skype:hover { background-color: #40beee; }
.about-social li.dribbble:hover { background-color: #c7366f; }
.about-social li.youtube:hover { background-color: #cc2423; }
.about-social li.vimeo:hover { background-color: #20b9eb; }
.about-social li.pagelines:hover { background-color: #364146; }
.about-social li > a > i { color: #0f0f16; font-size: 0.875rem; line-height: 2.5; transition: color 0.2s ease-in-out 0s; }
.about-social li:hover > a > i { color: #ffffff; }

/*===================================================================================*/
/*	HOMEPAGE BLOG SECTION
/*===================================================================================*/

.home-news { padding: 70px 0 30px; margin: 0; width: 100%; }
.home-news .post { background-color: #ffffff; border: 1px solid #e9e9e9; border-radius: 0; margin-bottom: 40px; padding: 25px 15px; transition: all 0.4s ease 0s; }
.home-news .post-thumbnail { margin: 0px 0 20px; position: relative; }
.home-news .post-thumbnail img { transition: all 300ms ease-out 0s; width: 100%; opacity: 1; }
.home-news .post .entry-header { margin: 0 0 21px; }
.home-news .post .entry-header .entry-title { color: #0f0f16; line-height: 1.3; margin: 0px; font-weight: 700; margin: 0 0 10px; }
.entry-header .entry-title > a { color: #0f0f16; text-decoration: none; transition: all 0.4s ease 0s; }

/*===================================================================================*/
/*	BLOG META
/*===================================================================================*/

.entry-meta {
	color: #000000;
	font-size: 0.813rem;
	line-height: 1.5;
	font-weight: 600;
	margin: 0 0 15px;
	padding: 0;
	width: 100%;
	overflow: hidden;
}
.entry-meta > span { color: #b9b9b9; margin: 0px 0px 0px 10px; margin: 0px 0px 0px 10px; }
.entry-meta a { color: #9f9f9f; font-weight: 700; padding: 0px 2px 0px 0; display: inline-block; transition: all 0.3s ease 0s; }
/*Meta Date*/
.entry-meta .entry-date { margin: 0; }
.entry-meta .entry-date > a { color: #fff; font-weight: 600; padding: 0px 10px; margin: 0; }
.entry-meta .entry-date > a:hover, .entry-meta .entry-date > a:focus,
.blog-section .entry-meta .entry-date > a:hover, .blog-section .entry-meta .entry-date > a:focus { color: #fff; }
/*Edit Post*/
.edit-link .post-edit-link { font-weight: 700; color: #0f0f16; }
.edit-link .post-edit-link:hover { text-decoration: underline; }
/*More Link*/
.home-news .more-link { margin: 0px; background-color: transparent; color: #0f0f16 !important; }
.blog-section .more-link { margin: 0px; background-color: transparent; color: #0f0f16 !important; }
.home-news .more-link,
.blog-section .more-link {
	font-size: 0.938rem;
	font-weight: 800;
    box-shadow: none;
    display: inline-block;
    transition: all 0.3s ease 0s;
}
.home-news .more-link::after,
.blog-section .more-link::after {
    content: "\f178";
    font-family: FontAwesome;
    margin: 0 7px 0 0;
    padding: 0;
    float: left;
	font-weight: 100;
	position: relative;
}


/*===================================================================================*/
/*	BLOG SECTION
/*===================================================================================*/

.blog-section { background: transparent; margin: 0px 0 40px; padding: 0; width: 100%; }
.blog-section .post { background-color: #ffffff; border: 1px solid #e9e9e9; border-radius: 0; margin-bottom: 40px; padding: 30px 15px 25px; transition: all 0.4s ease 0s; }
.blog-section .post.sticky { -webkit-box-shadow: 0px 0px 25px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 0px 25px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 0px 25px 0px rgba(0, 0, 0, 0.2);
    background-color: #efefef; border: 1px solid #e9e9e9; border-radius: 0; margin-bottom: 40px; padding: 30px 15px 25px; transition: all 0.4s ease 0s; }
.blog-section .post.sticky .entry-header .entry-title > a {
    color: #0f0f16;
}
.blog-section .post.sticky .entry-header .entry-title > a:hover, .blog-section .post.sticky a:hover
{
	color: #ce1b28;
}
.blog-section .post.sticky .entry-date a
{
color: #fff;
}
.blog-section .post.sticky a
{
color: #9f9f9f;
}
.blog-section .post-thumbnail {
    margin: 0px 0 20px;
	position: relative;
	transition: all 200ms ease-out 0s;
}
.blog-section .post .entry-header { margin: 0 0 21px; }
.blog-section .post .entry-header .entry-title { font-weight: 700; line-height: normal; margin: 0px 0 15px; padding: 2px 0 0; }
.blog-section .post .entry-header .entry-title > a { text-decoration: none; transition: all 0.4s ease 0s; }
.blog-section .post .entry-content { display: block; overflow: hidden; margin: 0px; }
.blog-section .entry-meta { font-size: 0.875rem; }
.post.format-link .entry-content p a {
	box-shadow: 0 1px 0 0 currentColor;
}
.post.format-link .entry-content p a:hover,
.post.format-link .entry-content p a:focus {
	box-shadow: none;
}

/*===================================================================================*/
/*	BLOG PAGINATION
/*===================================================================================*/

.blog-pagination { margin: 0 0 40px; overflow: hidden; padding: 0; text-align: center; }
.blog-pagination a {
	background-color: #ffffff; border: 1px solid #dbdbdb; color: #242526;
	cursor: pointer;
	display: inline-block;
	font-family: 'OpenSansSemiBold';
	transition: all 0.3s ease 0s;
	font-size: 	1.125rem;
	border-radius: 50%;
	margin: 0 3px 10px;
	padding: 8px;
	vertical-align: baseline;
	white-space: nowrap;
	width: 40px;
	height: 40px;
}
.blog-pagination a:hover, .blog-pagination a.active {
	background-color: #ee591f;
	border: 1px solid #ee591f;
	color: #FFFFFF;
}

/*===================================================================================*/
/*	BLOG POST AUTHOR
/*===================================================================================*/

.blog-author { background-color: #ffffff; border: 1px solid #e9e9e9; float: none; margin: 0 0 40px 0px; padding: 30px 25px; }
.blog-author img { border: 3px solid #fff;
	-moz-box-shadow: 0px 0px 1px #ccc;
	-webkit-box-shadow: 0px 0px 1px #ccc;
	box-shadow: 0px 0px 1px #ccc; height: 100px; margin-left: 15px; width: 100px; }
.blog-author h6 { color: #0f0f16; margin: 0 0 15px; }
.blog-author p { margin: 0px; }
.blog-author-social { margin: 20px 0 0; padding: 0; }
.blog-author-social li {
	background-color: #ffffff;
	border: 1px solid #21202e;
	cursor: pointer;
	display: inline-block;
	-webkit-border-radius: 2px;
	-moz-border-radius: 2px;
	border-radius: 2px;
	min-height: 1.876rem;
    min-width: 1.876rem;
	margin-bottom: 0px;
	margin-left: 0px;
	margin-top: 0px;
	padding: 0px;
	text-align: center;
	transition: background 0.2s ease-in-out 0s;
}
.blog-author-social li.facebook:hover { background-color: #4c66a4; border: 1px solid #4c66a4; }
.blog-author-social li.twitter:hover { background-color: #15b4c9; border: 1px solid #15b4c9; }
.blog-author-social li.linkedin:hover { background-color: #006599; border: 1px solid #006599; }
.blog-author-social li.skype:hover { background-color: #40beee; border: 1px solid #40beee; }
.blog-author-social li.dribbble:hover { background-color: #c7366f; border: 1px solid #c7366f; }
.blog-author-social li.youtube:hover { background-color: #cc2423; border: 1px solid #cc2423; }
.blog-author-social li.vimeo:hover { background-color: #20b9eb; border: 1px solid #20b9eb; }
.blog-author-social li.pagelines:hover { background-color: #364146; border: 1px solid #364146; }
.blog-author-social li > a { font-size: 0.875rem; line-height: 2; transition: 0.2s ease-in-out 0s; }
.blog-author-social li > a > i { color: #0f0f16; }
.blog-author-social li:hover > a > i { color: #ffffff; }

/*===================================================================================*/
/*	COMMENT FORM
/*===================================================================================*/

.comment-section { background-color: #ffffff; border: 1px solid #e9e9e9; float: none; margin: 0 0 40px 0px; padding: 30px 25px 5px; }
.comment-title { border-bottom: 1px dotted #c5d1dc; display: block; margin: 0 0 25px; padding: 0 0 15px; }
.comment-title h3 { color: #0f0f16; margin: 0; padding: 0; }
.comment-title h3 > i { color: #0f0f16; margin-left: 8px; }
.comment-box { margin: 0 !important; padding: 0; position: relative; }
.pull-left-comment { float: right; margin-left: 25px; width: 70px; height: auto; }
.comment-img { border-radius: 100%; max-width: 100%; margin: 2px 0 20px;  }
.comment-detail { border-bottom: 1px dotted #c5d1dc; margin-bottom: 40px; margin-right: 0; padding: 0 0 25px; }
.comment-detail-title { color: #0f0f16; margin: 0 0 15px; }
.comment-date { float: left; margin: 0; padding-right: 7px; vertical-align: middle; }
.comment-detail p { margin: 0 0 27px; }
.reply a { color: #ffffff; border-radius: 2px; display: inline-block; font-size: 0.813rem; padding: 3px 15px; }
.reply a:hover { color: #ffffff; }

.comment-form-section { background-color: #ffffff; border: 1px solid #e9e9e9; float: none; margin: 0 0 40px 0px; padding: 30px 25px; }
.form-inline .blog-form-group { display: inline-block; margin-bottom: 0; margin-left: 5px; vertical-align: middle; width: 100%; }
.blog-form-control, .blog-form-control-textarea { margin-bottom: 20px; }
.form-inline .blog-form-group-textarea { margin-bottom: 0; }
.blogdetail-btn, .blogdetail-btn { display: block; margin: 0 0 10px; }
.blogdetail-btn, .blogdetail-btn a {
	color: #ffffff;
	border-radius: 2px;
	display: inline-block;
	font-size: 0.875rem;
	font-weight: 600;
	margin-bottom: 0;
	padding: 10px 20px;
	text-align: center;
	transition: all 0.4s ease 0s;
	border: 0 none;
}
.blogdetail-btn:hover, .blogdetail-btn a:hover { color: #ffffff; }
.blog-form-control::-webkit-input-placeholder,
.blog-form-control-textarea::-webkit-input-placeholder {
	color: #64646d;
}
.blog-form-control::-moz-placeholder,
.blog-form-control-textarea::-moz-placeholder {
	color: #64646d;
}
.blog-form-control:-ms-input-placeholder,
.blog-form-control-textarea:-ms-input-placeholder {
	color: #64646d;
}
.blog-form-control-textarea {
	background-color: transparent;
    border: 1px solid #e9e9e9;
    color: #555;
}

/*===================================================================================*/
/*	BLOG POST ALL FORMATS
/*===================================================================================*/

/*Post Format - Video*/
.video-wrapper {
    margin: 0 0 20px;
	position: relative;
	padding-bottom: 56.25%;
	padding-top: 0px;
	height: 0;
	overflow: hidden;
}
.video-wrapper iframe {
	width:100%;
	height:300px;
	border: 0 none;
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}
/*Post Format - Aside*/
.blog-section .post.format-aside p { font-size: 1.125rem; }
/*Post Format - Audio*/
.audio-player {
    bottom: 0;
    padding: 0px 40px;
    position: absolute;
    left: 0;
	right: 0;
    z-index: 1;
}
/*Post Format - Link*/
.blog-section .post.format-link p { font-size: 	1.125rem; }
/*Post Format - Link*/
.gallery-content { margin: 0 0 20px !important; padding: 0; }
/*Post Format - Aside*/
.status-content { display: block; margin: 0; overflow: hidden; padding: 20px 25px; }
.status-content p { font-size: 1.125rem; margin: 0; padding: 0; }
/*Post Format - Chat*/
.chat-content { display: block; margin: 0 0 0px; overflow: hidden; }
.chat-content p { font-size: 1.000rem; margin: 0 0 10px; padding: 0; }
.chat-content p:last-child { margin: 0 0 0px; }

/*===================================================================================*/
/*	SIDEBAR SECTION
/*===================================================================================*/

.sidebar { margin-bottom: 0px; margin-right: 0; padding: 0px; }
.sidebar .widget { background-color: #ffffff; border: 1px solid #e9e9e9; margin: 0 0 40px; overflow: hidden; padding: 0; }
.sidebar .section-header { background-color: #21202e; width: 100%; margin-bottom: 0px; margin-top: 0px; padding: 16px 20px; display: block; text-align: right; }
.sidebar .section-header .widget-title { color: #ffffff; font-size: 1.250rem; margin: 0; padding-bottom: 0px; word-wrap: break-word; }
.sidebar-menu-box { display: block; }
.sidebar .section-header .widget-title .rsswidget,
.header-sidebar .section-header .widget-title .rsswidget,
.footer-sidebar .section-header .widget-title .rsswidget { color: #fff; }
.sidebar .widget.widget_text select { width: 100%; margin: 0; }
.sidebar .widget ul, .sidebar .widget.widget_rss ul, .sidebar .widget .calendar_wrap, .sidebar .widget .textwidget, .sidebar .widget.widget_rss ul
.sidebar .widget .gallery, .sidebar .widget img.image, .sidebar .widget .search-form, .sidebar .widget .tagcloud  {
	margin: 0;
	padding: 30px 25px;
}
.sidebar .section-header {
    border-right: 5px solid #ce1b28;
}
.sidebar form.search-form label { padding: 0; }
.sidebar .widget label { display: block; padding: 25px 25px 0; margin: 0; }
.sidebar .widget select { margin: 0; margin: 30px 25px; width: 85%; }
.sidebar .widget .cont-social { padding: 0; }
/*Widget Audio*/
.sidebar .widget.widget_media_audio .mejs-audio { max-width: 85%; height: auto; margin: 30px 25px; }
/*Widget Video*/
.sidebar .widget.widget_media_video .wp-video { max-width: 85%; height: auto; margin: 30px 25px; }
.sidebar .widget.widget_media_video .wp-video iframe { width: 100%; }
/*Sidebar Latest Post - Custom Widget*/
.widget .post { background: transparent; border-bottom: 1px dotted #c5d1dc; border-right: 0 none; border-left: 0 none; border-top: 0 none; margin-bottom: 17px; margin-top: 0 !important; padding: 0 0 17px 0; overflow: hidden; }
.widget .post:last-child { margin-bottom: 0px; padding-bottom: 0px; border-bottom: 0px; }
.widget .post .entry-title { color: #0f0f16; display: block; font-size: 1.250rem; margin-bottom: 10px; margin-top: -4px; word-wrap: break-word; }
.widget .post .entry-title a { color: #0f0f16; transition: all 0.3s ease 0s; }
.widget .post .entry-content { margin: 0px; display: block; }
.widget .post a.post-thumbnail { display: block; float: right; width: 90px; margin-right: 0; margin-left: 25px; padding: 1px; }
.widget .post a.post-thumbnail img { border-radius: 0px;
	border: 4px solid #fff;
	-moz-box-shadow: 0px 0px 2px #ccc;
	-webkit-box-shadow: 0px 0px 2px #ccc;
	box-shadow: 0px 0px 2px #ccc;  display: block; height: auto; max-width: 100%; transition: all 0.3s ease-in-out 0s; }
.widget .post:hover a.post-thumbnail img { opacity: 0.7px; }
.sidebar .widget .post {
    margin: 30px 25px !important;
    padding: 0;
}
/*Sidebar Calender Widget*/
.widget_calendar {}
.widget table#wp-calendar {
	color: #64646d;
	font-weight: 500;
	font-size: 0.938rem;
	border-collapse: separate;
	border-spacing: 0;
	border-width: 1px 1px 0 0;
	margin: 0;
	text-align: center;
	table-layout: fixed;
	width: 100%
}
.widget table#wp-calendar caption {
	color: #ffffff;
	text-align: center;
	font-weight: 600;
	font-size: 1.000rem;
    margin: 0;
	padding: 10px 0;
}

.widget table#wp-calendar, .widget table#wp-calendar th, .widget table#wp-calendar td { background-color: #fff; border: 1px solid rgba(51, 51, 51, 0.1); text-align: center; padding: 0.250rem 0; border-width: 0 0 1px 1px; line-height: 1.9375; }
.widget table#wp-calendar a { color: #000000; font-weight: 600; }
.widget table#wp-calendar #next a, .widget table#wp-calendar #prev a { font-weight: 600; color: #000000; }
/*Sidebar Widget Archive, Widget categories, Widget Links, Widget Meta, widget Nav Menu, Widget Pages, Widget Recent Comments, Widget Recent Entries */
.widget_archive ul, .widget_categories ul, .widget_links ul, .widget_meta ul, .widget_nav_menu ul, .widget_pages ul,
.widget_recent_comments ul, .widget_recent_entries ul {
    list-style: outside none none;
}
.widget_archive li:first-child, .widget_categories li:first-child, .widget_links li:first-child, .widget_meta li:first-child, .widget_nav_menu li:first-child,
.widget_pages li:first-child, .widget_recent_comments li:first-child, .widget_recent_entries li:first-child {
    border-top: 0 none;
    padding-top: 0;
}
.widget_archive li:last-child, .widget_categories li:last-child, .widget_links li:last-child, .widget_meta li:last-child, .widget_nav_menu li:last-child,
.widget_pages li:last-child, .widget_recent_comments li:last-child, .widget_recent_entries li:last-child {
    padding-bottom: 0px;
	border-bottom: 0 none !important;
	margin-bottom: 0;
}
.widget_archive li, .widget_categories li, .widget_links li, .widget_meta li, .widget_nav_menu li, .widget_pages li,
.widget_recent_comments li, .widget_recent_entries li {
    font-weight: 500;
	border-bottom: 1px dotted #c5d1dc;
    margin: 0 0 12px;
    padding: 0px 25px 12px 0px;
	position: relative;
}
.widget_archive li:before, .widget_categories li:before, .widget_links li:before,
.widget_meta li:before, .widget_nav_menu li:before, .widget_pages li:before,
.widget_recent_comments li:before, .widget_recent_entries li:before {
    position: absolute;
    top: 0;
    right: 0;
    content: '\f00c';
    font-family: 'FontAwesome';
}
.widget_archive a, .widget_categories a, .widget_links a, .widget_meta a, .widget_nav_menu a, .widget_pages a,
.widget_recent_comments a, .widget_recent_entries a {
    border: 0 none;
	transition: all 0.3s ease 0s;
	color: #64646d;
}
.widget_recent_comments a::before {
	content: "";
	font-family: FontAwesome;
	display: none;
	margin-left: 10px;
	margin-right: 1px;
	font-size: 0.875rem;
}
.widget ul#recentcomments li.recentcomments span.comment-author-link { font-weight: 700; color: #64646d; }

/*Blog Pagination*/


/*Sidebar Search*/
form.search-form span.screen-reader-text {
    clip: rect(1px, 1px, 1px, 1px);
	font-size: 1.000rem;
	font-weight: 500;
    height: 1px;
    overflow: hidden;
    position: absolute !important;
    width: 1px;
}
form.search-form input.search-field {
	margin: 0 0 20px;
}
input[type="reset"] { background-color: #21202e; }
form.search-form input.search-submit,
input[type="submit"], input[type="reset"],
.woocommerce-product-search input[type="submit"] {
	color: #ffffff;
	border: 0 none;
    border-radius: 0px;
    display: inline-block;
	font-size: 0.875rem;
	height: 45px;
    margin: 0;
    padding: 12px 22px;
    text-align: center;
    transition: all 0.4s ease 0s;
}
/*Input Type Fields*/
input[type="text"], input[type="email"], input[type="url"], input[type="password"],
input[type="search"], input[type="number"], input[type="tel"], input[type="range"],
input[type="date"], input[type="month"], input[type="week"], input[type="time"],
input[type="datetime"], input[type="datetime-local"], input[type="color"], select {
	height: 45px;
}
input[type="text"], input[type="email"], input[type="url"], input[type="password"],
input[type="search"], input[type="number"], input[type="tel"], input[type="range"],
input[type="date"], input[type="month"], input[type="week"], input[type="time"],
input[type="datetime"], input[type="datetime-local"], input[type="color"], select, textarea {
	padding: 6px 12px;
	border-radius: 0px;
	font-size: 0.875rem;
	letter-spacing: 1px;
	font-weight: 600;
	-webkit-box-shadow: none;
	box-shadow: none;
    color: #555;
    background: #fff;
    background-image: -webkit-linear-gradient(rgba(255, 255, 255, 0), rgba(255, 255, 255, 0));
    border: 1px solid #e9e9e9;
    display: block;
    width: 100%;
}
.radio, .checkbox { display: inline-block; }
input[type="radio"], input[type="checkbox"] { margin: 0.625rem 0 0 0.5rem; }

/* Navigation Post*/
.navigation.pagination { margin: 0px 0 20px; overflow: hidden; padding: 0; text-align: center; display: block; }
.navigation.pagination a, .navigation.pagination a {
	background-color: transparent; border: 1px solid #0f0f16; color: #242526;
  cursor: pointer;
  display: inline-block;
  line-height: 1.1;
  font-weight: 600;
  transition: all 0.3s ease 0s;
  font-size: 1.125rem;
  border-radius: 0px;
  margin: 0 0px 10px;
  padding: 8px;
  vertical-align: baseline;
  white-space: nowrap;
  width: 37px;
  height: 37px;
}


.navigation.pagination .nav-links .page-numbers.current,  .navigation.pagination .nav-links a:hover { background-color: #0f0f16; border: 1px solid #0f0f16; color: #FFFFFF; width: 37px;
  height: 37px; cursor: pointer;
    display: inline-block;
    line-height: 1.1;
    font-weight: 600;
    transition: all 0.3s ease 0s;
    font-size: 1.125rem;
    border-radius: 0px;
    margin: 0 0px 10px;
    padding: 8px;
    vertical-align: baseline;
    white-space: nowrap;
    width: 37px;
    height: 37px; }

.navigation.pagination { margin: 0; display: block; }

/*Widget Select*/
.widget label { margin: 0 0 20px }
.header-sidebar .widget label, .footer-sidebar .widget label { color: #fff; margin: 0 0 20px }
.widget select {
    width: 100%;
	padding: 6px 12px;
    height: 45px;
    border-radius: 2px;
    font-size: 0.875rem;
	border: 1px solid #e9e9e9;
}
/*Rss Widget*/
.widget.widget_rss ul { list-style: none; padding: 0; }
.widget.widget_rss ul li { padding: 0 0 20px; }
.widget .rssSummary { padding: 10px 0; }
/*Sidebar Tags*/
.tagcloud { margin: 0px; overflow: hidden; padding: 0; }
.tagcloud a {
	background-color: #f9f9f9; border: 1px solid #e9e9e9; color: #64646d;
    cursor: pointer;
    display: inline-block;
	font-size: 0.938rem !important;
    margin: 0 0 10px 5px;
    padding: 6px 14px;
    transition: all 0.3s ease 0s;
    vertical-align: baseline;
    white-space: nowrap;
}
.tagcloud a:hover { color: #ffffff; }

/*===================================================================================*/
/*	HEADER SIDEBAR & FOOTER SIDEBAR SECTION
/*===================================================================================*/

.site-footer { background-color: #21202e; margin: 0; padding: 80px 0 0; width: 100%; }
.footer-sidebar { padding: 0; }
.header-sidebar .widget, .footer-sidebar .widget { background-color: transparent; border: 0 none; margin: 0 0 40px; overflow: hidden; padding: 0; }
.header-sidebar .section-header, .footer-sidebar .section-header { border-bottom: 1px solid #363544; width: 100%; padding: 0 0 15px; margin: 0 0 40px; display: block; text-align: right; }
.header-sidebar .widget .post, .footer-sidebar .widget .post {
	background: transparent;
	border-bottom: 1px dotted #403f4e;
	border-right: 0 none;
    border-left: 0 none;
    border-top: 0 none;
}
.footer-sidebar .widget .post .entry-title, .footer-sidebar .widget .post .entry-title a,
.header-sidebar .widget .post .entry-title, .header-sidebar .widget .post .entry-title a {
	color: #ffffff;
}
.footer-sidebar .widget .post .entry-content p, .header-sidebar .widget .post .entry-content p { color: #9595a0; }
.footer-sidebar .widget .post a.post-thumbnail img, .header-sidebar .widget .post a.post-thumbnail img {
	border-radius: 0px;
	border: 4px solid #21202e;
	-moz-box-shadow: 0px 0px 2px #ffffff;
	-webkit-box-shadow: 0px 0px 2px #ffffff;
	box-shadow: 0px 0px 2px #ffffff;
}
.header-sidebar .section-header .widget-title, .footer-sidebar .section-header .widget-title {
	color: #ffffff;
	font-weight: 400;
	margin: 0;
	padding-bottom: 0px;
	word-wrap: break-word;
}
.header-sidebar .section-header span,
.footer-sidebar .section-header span {
	bottom: 2px;
    display: block;
    height: 4px;
    margin: 0;
    position: absolute;
	bottom: -2px;
	right: 0;
    width: 30px;
}
.footer-sidebar .widget_archive ul, .footer-sidebar .widget_categories ul, .footer-sidebar .widget_links ul,
.footer-sidebar .widget_meta ul, .footer-sidebar .widget_nav_menu ul, .footer-sidebar .widget_pages ul,
.footer-sidebar .widget_recent_comments ul, .footer-sidebar .widget_recent_entries ul,

.header-sidebar .widget_archive ul, .header-sidebar .widget_categories ul, .header-sidebar .widget_links ul,
.header-sidebar .widget_meta ul, .header-sidebar .widget_nav_menu ul, .header-sidebar .widget_pages ul,
.header-sidebar .widget_recent_comments ul, .header-sidebar .widget_recent_entries ul {
	padding: 0;
	margin: 0;
}
.footer-sidebar .widget_archive li, .footer-sidebar .widget_categories li, .footer-sidebar .widget_links li, .footer-sidebar .widget_meta li,
.footer-sidebar .widget_nav_menu li, .footer-sidebar .widget_pages li, .footer-sidebar .widget_recent_comments li, .footer-sidebar .widget_recent_entries li,

.header-sidebar .widget_archive li, .header-sidebar .widget_categories li, .header-sidebar .widget_links li, .header-sidebar .widget_meta li,
.header-sidebar .widget_nav_menu li, .header-sidebar .widget_pages li, .header-sidebar .widget_recent_comments li, .header-sidebar .widget_recent_entries li {
    border-bottom: 1px dotted #403f4e;
}
.header-sidebar .widget_archive a, .header-sidebar .widget_categories a, .header-sidebar .widget_links a, .header-sidebar .widget_meta a, .header-sidebar .widget_nav_menu a, .header-sidebar .widget_pages a, .header-sidebar .widget_recent_comments a, .header-sidebar .widget_recent_entries a, .header-sidebar p,
.header-sidebar dl, .header-sidebar ul > li, .header-sidebar ol > li, .header-sidebar address,
.header-sidebar .wp-caption .wp-caption-text, .header-sidebar .gallery-caption, .header-sidebar .entry-caption {
	color: #fff;
}
.footer-sidebar .widget_archive a, .footer-sidebar .widget_categories a, .footer-sidebar .widget_links a, .footer-sidebar .widget_meta a, .footer-sidebar .widget_nav_menu a, .footer-sidebar .widget_pages a, .footer-sidebar .widget_recent_comments a, .footer-sidebar .widget_recent_entries a, .footer-sidebar p,
.footer-sidebar dl, .footer-sidebar ul > li, .footer-sidebar ol > li, .footer-sidebar address,
.footer-sidebar .wp-caption .wp-caption-text, .footer-sidebar .gallery-caption, .footer-sidebar .entry-caption {
    color: #9595a0;
}
.footer-sidebar h1, .footer-sidebar h2, .footer-sidebar h3, .footer-sidebar h4, .footer-sidebar h5, .footer-sidebar h6,
.header-sidebar h1, .header-sidebar h2, .header-sidebar h3, .header-sidebar h4, .header-sidebar h5, .header-sidebar h6 {
	color: #fff;
}
.header-sidebar .sm-cont-widget, .footer-sidebar .sm-cont-widget {
	background-color: transparent;
    border: 0 none;
	padding: 0;
}
.header-sidebar .sm-cont-widget address, .header-sidebar .sm-cont-widget address > a { color: #fff; }
.footer-sidebar .sm-cont-widget address, .footer-sidebar .sm-cont-widget address > a { color: #9595a0; }
.header-sidebar .custom-social-icons li, .footer-sidebar .custom-social-icons li {
    border: 1px solid #21202e;
}

.txt-white { color: #fff; }
.bg-white { background-color: #fff !important; }

/*===================================================================================*/
/*	FOOTER COPYRIGHTS - SITE INFO
/*===================================================================================*/

.site-info { border-top: 1px dotted #403f4e; padding: 25px 0; text-align: center; }
.site-info p { color: #c4c4c4; margin: 0; padding: 0; }
.site-info a { color: #fff; }

/*===================================================================================*/
/*	WP THEME DATA - CUSTOM HTML TAGS
/*===================================================================================*/

/* Ul and ol lists */
ul, ol { font-weight: normal; margin: 20px 0 0; }
ul > li, ol > li { margin: 0; padding: 4px 0; }
ul, ol { padding: 0 20px 0 0; }
li > ul, li > ol { margin-bottom: 0; margin-right: 1.5em; }
/*Blockquote*/
blockquote { background-color: #f2f2f2; margin: 5px 0 20px; font-size: 1.250rem; }
blockquote p { font-size: 18px; margin: 0 !important; }
blockquote cite, blockquote small{ color: #0f0f16; display: block; font-size: 1rem; line-height: 1.75; font-weight: 600; margin: 10px 0 0; }
blockquote a  { color: #0f0f16; font-size: 1rem; line-height: 1.75; font-weight: 600; margin: 10px 0 0; }
/*Address*/
address { font-style: normal; margin: 0 0 20px; line-height: 27px; font-size: 16px; }
address span, address p { display: block; padding: 0 0 10px; }
address span:last-child { padding-bottom: 0; }
/*Table*/
table {
	font-weight: 500;
	font-size: 0.938rem;
	border-spacing: 0;
	border-width: 1px 1px 0 0;
	table-layout: fixed;
	width: 100%;
	margin: 0 0 25px;
	padding: 0;
}
table, table th, table td { background-color: #fff; color: #64646d; border: 1px solid rgba(51, 51, 51, 0.1); }
table th, table td { padding: 0.7rem; }
table th { border-width: 0 0 1px 1px; font-weight: 700; }
table caption, table th, table td { text-align: right; }
table a { text-decoration: none; }
/*Definition Lists*/
dl { margin-bottom: 20px; margin-top: 0; }
dl dt { font-weight: 700; margin-bottom: 5px; }
dl dd { margin-bottom: 20px; margin-right: 20px; line-height: 27px; }
/*Abriviation, Acronym, Big, Strike, del, em, Ins, cite, q*/
abbr { text-decoration: none; cursor: help; }
tla, acronym { text-decoration: underline; cursor: help; }
acronym { border-bottom: 0 none; }
big { font-size: larger; font-weight: 600; }
s, strike, del { text-decoration: line-through; }
em, cite, q { font-style:italic; }
ins, mark { color: #ffffff; text-decoration: none; padding: 0 3px; }
code { color: #444444; }
pre {
    padding: 30px;
    margin: 0 0 20px;
    font-size: 15px;
    color: #64646d;
    max-width: 100%;
	background-color: #fff;
    border: 1px solid #e4e8ea;
    border-radius: 0px;
    white-space: pre-wrap;
}
code, kbd, tt, var, samp, pre {
    font-family: Inconsolata, monospace;
    -webkit-hyphens: none;
    -moz-hyphens: none;
    -ms-hyphens: none;
    hyphens: none;
}
address{ font-style: italic;}
#attachment_906 { width: auto; }

/*===================================================================================*/
/*	WP DEFAULT CLASSES
/*===================================================================================*/

.sticky{}
cite{ font-style: italic !important; }
.bypostauthor{}
#attachment_907 { width: 100% !important; }
.alignnone img{ display: block; height: auto; width: 99%; }
img.alignleft, .wp-caption.alignleft{ margin-left: 30px; }
img.alignright, .wp-caption.alignright{ margin-right: 30px; float: left;}
img.wp-caption .alignnone { display: block; margin: 0 auto; height: auto; width: 100%; }
.wp-caption .wp-caption-text, .gallery-caption, .entry-caption{
	clear: right;
    font-style: italic;
    line-height: 1.5em;
    margin: 0.75em 0;
    text-align: center;
}
.wp-caption.alignright { margin: 5px 20px 20px 0;}
.wp-caption p.wp-caption-text {
	font-size: 14px;
	margin: 12px 0;
	text-align: center;
	font-style: italic;
	line-height: 1.5em;
}
.wp-caption.alignleft { margin: 5px 0 20px 20px;}
.gallery .gallery-icon img {
	height: auto;
	max-width: 90%;
	padding: 0;
	border: 5px solid #fff !important;
	-moz-box-shadow: 0 0 5px 2px rgba(33, 28, 28, .3);
	-webkit-box-shadow: 0 0 5px 2px rgba(33, 28, 28, .3);
	box-shadow: 0 0 5px 2px rgba(33, 28, 28, .3);
}
.gallery-item .gallery-caption, .hc_service_column .gallery-item .gallery-caption {
	font-size: 14px;
	margin: 12px 0;
	text-align: center;
	font-style: italic;
	line-height: 1.5em;
}
a img.alignright { float: left; }
a img.alignnone { margin: 5px 0 20px 20px; }
a img.alignleft { float: right; }
a img.aligncenter { display: block; margin-right: auto; margin-left: auto; }
@media screen and (min-width: 30rem){
	img.alignleft { float: right; margin-left: 20px; }
}
.alignleft { display: inline; float: right; margin-left: 20px; }
.aligncenter { clear: both; display: block; margin-right: auto; margin-left: auto; }
fieldset {
    margin-bottom: 1rem;
    border: 1px solid #e9e9e9;
    margin: 0 2px;
    padding: 0.35rem 0.950rem 0.75rem;
}
fieldset p { margin: 0px 0 20px; }
legend {
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
	font-size: 1.500rem;
	color: #0f0f16;
	font-weight: 600;
	display: table;
	max-width: 100%;
	border-bottom: none;
	width: auto;
	padding: 0;
	white-space: normal;
}

/*===================================================================================*/
/*	CONTACT SECTION
/*===================================================================================*/

.contact-section { background: transparent; margin: 0px; padding: 0; width: 100%; }
.cont-form-section {background-color: #ffffff;border: 1px solid #e9e9e9;margin: 0 0 30px 0px;padding: 30px 25px;}
.sm-cont-widget { margin-bottom: 0px; margin-top: 0; overflow: hidden; padding: 30px 25px; }
.cont-description { display: block; overflow: hidden; margin: 0 0 28px; }
.cont-description p { margin: 0; padding: 0; }
.cont-info { display: block; overflow: hidden; margin: 0 0 30px; }
.cont-info address { color: #64646d; margin-bottom: 12px; font-style: normal; }
.cont-info address > i { margin-left: 7px; margin-right: 1px; }
.cont-info address > a { color: #64646d; font-weight: 600; }
.cont-title { color: #0f0f16; font-weight: 600; margin-top: 0px; margin-bottom: 20px; }
.map-section { float: none; margin: 30px 0 80px; }
.cont-google-map { border: 5px solid #ffffff; box-shadow: 0 0 1px 0 #ccc; margin-bottom: 50px; margin-top: 20px; margin: 0px; }

/*===================================================================================*/
/*	404 ERROR PAGE SECTION
/*===================================================================================*/

.404-section { margin: 0 0 30px; padding: 0; width: 100%; }
.error_404 { clear: both; margin: 0 auto; padding: 30px 0 70px; text-align: center; width: 50%; }
.error_404 h1 { font-size: 14rem; line-height: 1.1; margin: 20px 0;  }
.error_404 h1 > i { font-size: 13rem; padding: 0 10px; }
.error_404 h4 { color: #0f0f16; margin: 20px 0px 25px; font-size: 3rem; }
.error_404 p { margin-bottom: 25px; font-size: 1.125rem; font-weight: 500; letter-spacing: 1px; }

.error_404_btn {
   display: inline-block;
   font-size: 14px;
   line-height: 20px;
    font-weight: 600;
   margin: 8px 0;
   padding: 12px 25px;
    border-radius: 2px;
   text-align: left;
   text-transform: uppercase;
   transition: all 0.3s ease 0s;
   vertical-align: middle;
}
.error_404_btn:hover, .error_404_btn:focus {
  color: #ffffff;
}
.error_404_btn .fa { padding-left: 7px; }
/*===================================================================================*/
/*	GALLERY SECTION
/*===================================================================================*/

.gallery-section { margin: 10px 0 40px; padding: 0; }
.gallery-area { margin: 0 0 40px; }
.gallery-section .gallery-image {
	border: 4px solid #fff;
    -moz-box-shadow: 0px 0px 2px #ccc;
    -webkit-box-shadow: 0px 0px 2px #ccc;
    box-shadow: 0px 0px 1px #ccc;
}
.gallery-section .gallery-thumbnail {
    width: 100%;
	overflow: hidden;
	position: relative;
	transition: all 200ms ease-out 0s;
}
.gallery-section .gallery-thumbnail img { transition: all 300ms ease-out 0s; width: 100%; opacity: 1; }
.gallery-section .gallery-image .gallery-thumbnail:hover img {
	-webkit-transform: scale(1.15);/* Saf3.1+, Chrome */
	-moz-transform: scale(1.15); /* FF3.5+ */
	-ms-transform: scale(1.15); /* IE9 */
	-o-transform: scale(1.15); /* Opera 10.5+ */
	transform: scale(1.15);
	opacity: 1;
}

.top-bottom { padding: 70px 0 30px; margin: 0; }
/*Gallery Lightbox*/
.gallery-showcase-overlay {
	background: rgba(0, 0, 0, 0.7);
	visibility: hidden;
	opacity: 0;
	transition: all 0.4s ease;
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	width: 100%;
	height: 100%;
	border-radius: 0;
	padding: 1.42857rem;
}
.gallery-section .gallery-image .gallery-thumbnail:hover .gallery-showcase-overlay { visibility: visible; opacity: 1; height: 100%; }
.gallery-section .gallery-image .gallery-thumbnail{
	text-align:center;
	position:relative;
	line-height:0px;
	font-size:0px;
	transition: all 200ms ease-out;
	-webkit-transition: all 200ms ease-out;
	width:100%;
	position:relative;
	height:100%;
	overflow:hidden;
}
.gallery-section .gallery-image .gallery-thumbnail .gallery-showcase-icons { margin: -20px 0 0; position: absolute; top: 50%; left: 0;width: 100%; }
.gallery-section .gallery-image .gallery-thumbnail .gallery-showcase-icons a {
    font-size: 1.250rem;
	line-height: 2.1;
    display: inline-block;
    margin: 0 10px 0 0;
    padding: 1px;
    opacity: 1;
	text-decoration: none;
	text-align: center;
	color: #0f0f16;

	width: 2.85714rem;
	height: 2.85714rem;
	border-radius: 50%;
	background-color: #fff;

    -wekbit-transition: all 0.4s;
    -moz-transition: all 0.4s;
    -o-transition: all 0.4s;
    transition: all 0.4s;
    -wekbit-transform: translateY(30px);
    -moz-transform: translateY(30px);
    -o-transform: translateY(30px);
    -ms-transform: translateY(30px);
    transform: translateY(30px);
}
.gallery-section .gallery-image .gallery-thumbnail:hover .gallery-showcase-icons a {
    -wekbit-transform: translateY(0);
    -moz-transform: translateY(0);
    -o-transform: translateY(0);
    -ms-transform: translateY(0);
    transform: translateY(0);
}
.gallery-section .gallery-image .gallery-thumbnail .gallery-showcase-icons a:hover { opacity: 1; }
.gallery-area .gallery-caption {
	color: #fff;
	font-size: 1.250rem;
    font-weight: 500;
    margin: 0 0 10px;
    text-shadow: -2px 2px 1px #000;
    -webkit-transition: all 0.7s;
    -moz-transition: all 0.7s;
    -o-transition: all 0.7s;
    transition: all 0.7s;
    -wekbit-transform: scale(0.8);
    -moz-transform: scale(0.8);
    -o-transform: scale(0.8);
    -ms-transform: scale(0.8);
    transform: scale(0.8);
}
.gallery-area:hover .gallery-caption {
    -wekbit-transform: scale(1);
    -moz-transform: scale(1);
    -o-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
}
.padding0 { padding-right: 0 !important; padding-left: 0 !important; }
.border0 { box-shadow: none !important; border: none !important; }

/*===================================================================================*/
/*	ADDITIONAL SECTION
/*===================================================================================*/

.bg-gallery { background-color: #ffffff; border-top: 1px solid #e8e8e8; border-bottom: 1px solid #e8e8e8; }

/*===================================================================================*/
/*	SCROLL BUTTON PAGE TO TOP
/*===================================================================================*/

.hc_scrollup {
	border-radius: 0px;
    bottom: 0px;
    padding: 3px;
    display: none;
    height: 40px;
    opacity: 1;
    position: fixed;
    right: 60px;
    text-align: center;
    width: 60px;
    overflow: hidden;
    z-index: 9999;
    color: #ffffff;
    font-size: 1.000rem;
    line-height: 1.9;
}
.hc_scrollup:hover { opacity: 1; }
.hc_scrollup i { color: #ffffff; font-size: 14px; }

/*===================================================================================*/
/*  WOOCOMMERCE CSS
/*===================================================================================*/
.woocommerce .woocommerce-result-count { margin: 1rem 0 1rem; }
.woocommerce .products ul, .woocommerce ul.products { margin: 0; }
.woocommerce ul.products li.product h3 { text-align: center; margin: 0rem 0 1rem; padding: 0; font-weight: 700; }
.woocommerce .products .star-rating { margin: 0 auto .5rem; }
.woocommerce .price { text-align: center; }
.woocommerce div.product p.price, .woocommerce div.product span.price { font-size: 1.25rem; }
.woocommerce ul.products li.product .price,
.woocommerce ul.products li.product .price del { font-size: 1.1rem; font-weight: 600; }
.woocommerce ul.products li.product .price del { display: inline-block; }
.woocommerce ul.products li.product .price ins, .price ins { font-weight: 600; color: #64646d; }
.woocommerce div.product p.price { text-align: right; font-weight: 600; }
.woocommerce ul.products li.product,
.woocommerce-page ul.products li.product { transition: all 0.6s; text-align: center; padding: 0.4rem 0.4rem 1.5rem; margin-bottom: 2rem; }
.woocommerce-page ul.products li.product:hover { box-shadow: 0 14px 25px 0 rgba(0,0,0,0.2); }
.woocommerce ul.products li.product .onsale, .woocommerce span.onsale {
    left: inherit;
    min-width: auto;
    min-height: auto;
    color: #fff;
    border-radius: 0;
    font-size: 0.750rem;
    line-height: 0.700rem;
    padding: .200rem .350rem .300rem;
    margin: 0;
    position: absolute;
    right: 10px;
    top: 10px;
    transition: all 0.5s;
}
.woocommerce ul.products li.product .button, .woocommerce a.added_to_cart {
	box-shadow: none;
	font-weight: 700;
	line-height: 1.3;
	border-radius: 0px;
	padding: .600rem 0.7rem;
	transition: all 0.5s;
	margin-top: 0.7rem;
	height: 38px;
}
.woocommerce a.button { border-radius: 0px; box-shadow: none; }
.woocommerce table.my_account_orders .order-actions .button { margin: 0 2px; }
.woocommerce table.my_account_orders .order-actions .button:last-child { margin-top: 4px; }
.woocommerce div.product form.cart .button, .woocommerce a.button, .woocommerce a.button:hover { padding: .700rem 1.2rem; }
.woocommerce .posted_in a, .woocommerce-product-rating a, .woocommerce .tagged_as a { transition: all 0.5s; font-weight: 600; }
.woocommerce div.product form.cart { margin-top: 2rem; padding: 0; }
.woocommerce div.product form.cart .variations { padding: 2rem 0; margin: 0 0 2rem; }
.woocommerce .variations td.label { padding: 0; font-size: 	0.938rem; }
.woocommerce div.product form.cart .variations select { padding: 6px 12px; height: 45px; border-radius: 2px; font-size: 0.875rem; border: 1px solid #e9e9e9; }
.woocommerce div.product form.cart .variations tr { display: block; padding: 0; }
.woocommerce div.product form.cart .variations td { display: list-item; list-style: none; text-align: right; line-height: 1.2rem; padding: 0rem; }
.woocommerce div.product form.cart .variations td.label label { font-family: 'Open Sans', Sans-serif; margin-bottom: 15px; }
.woocommerce .woocommerce-variation-price { margin: 0 0 1rem; }
.woocommerce-variation-price .woocommerce-Price-amount { font-weight: 600; }
.woocommerce-tabs { padding: 2rem 0 0; }
.woocommerce div.product #reviews .comment img,
.woocommerce-page div.product #reviews .comment img { border-radius: 100%; height: 70px; margin: 2px 0 20px; width: 70px; float: right; }
.woocommerce #reviews #comments ol.commentlist { padding: 0; }
.woocommerce #reviews #comments ol.commentlist li .comment-text { margin: 0 90px 0 0; }
#review_form_wrapper { margin: 3rem 0 2rem; }
.woocommerce #reviews #comments ol.commentlist li .meta strong { font-size: 1.000rem; }
.woocommerce #reviews #comments ol.commentlist li .meta time { font-size: 1.000rem; }
.woocommerce #reviews h3 { margin: 0 0 1rem; }
.woocommerce div.product .woocommerce-tabs .panel { box-shadow: none; padding: 1rem 1rem 1rem; border-radius: 0; }
.woocommerce-error li, .woocommerce-info li, .woocommerce-message li { padding: 0; }
.woocommerce-Tabs-panel h2, .woocommerce .related h2,
.woocommerce .cart-collaterals .cart_totals h2, .woocommerce-page .cart-collaterals .cart_totals h2 { font-size: 1.500rem; }
.woocommerce .related h2 { margin: 0 0 20px; }
.woocommerce table.shop_table { border-radius: 0; margin: 0 0 40px -1px; padding: 0; }
.woocommerce table.shop_table th { border: none; font-size: 1.000rem; padding: 12px; font-weight: 600; }
.woocommerce table.shop_table td { border-right: none; border-left: none; border-bottom: none; }
.woocommerce-cart table.cart td { font-weight: 600; padding: 15px 12px; }
.woocommerce-cart table.cart td a { font-weight: 600; transition: all 0.3s; }
.woocommerce-cart .cart-collaterals .cart_totals table td { vertical-align: middle; }
.woocommerce-cart .cart-collaterals .cart_totals tr th, .woocommerce table.shop_table td a { font-weight: 600; }
#add_payment_method table.cart img, .woocommerce-cart table.cart img, .woocommerce-checkout table.cart img { width: 70px; }
.woocommerce .quantity .qty { width: 3.5rem; text-align: right; height: 44px; padding: .500rem 0.7rem; border-radius: 0; }
.woocommerce td.product-name dl.variation { margin: .35rem 0 0; }
.woocommerce td.product-name dl.variation dt, .woocommerce td.product-name dl.variation dd, .woocommerce td.product-name dl.variation dd p { line-height: 20px; }
.woocommerce-cart table.cart td.actions .coupon .input-text { width: 200px; padding: 6px 12px; border-radius: 0; height: 44px; }
.woocommerce .cart input.button, .woocommerce input.button.alt, .woocommerce button.button, .woocommerce #respond input#submit {
	border-radius: 1px;
	padding: .600rem 0.7rem;
	transition: all 0.5s;
	height: 44px;
}
.woocommerce-page .cart input.button:hover,
.woocommerce .cart input.button:focus,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:focus,
.woocommerce input.button.alt:hover,
.woocommerce input.button.alt:focus,
.woocommerce input.button:hover,
.woocommerce input.button:focus,
.woocommerce button.button:hover,
.woocommerce button.button:focus,
.woocommerce #respond input#submit:hover,
.woocommerce #respond input#submit:focus {
	box-shadow: none;
}
.woocommerce div.product .woocommerce-tabs ul.tabs::before { border-bottom: 1px solid #e9e9e9; }
.woocommerce div.product .woocommerce-tabs ul.tabs li::before {
    -webkit-box-shadow: -2px 2px 0 #e9e9e9;
    box-shadow: -2px 2px 0 #e9e9e9;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li,
.woocommerce div.product .woocommerce-tabs ul.tabs li::after,
.woocommerce div.product .woocommerce-tabs ul.tabs li::before {
	border: 1px solid #e9e9e9;
}
.select2-container .select2-selection--single,
.select2-container--default .select2-selection--single .select2-selection__arrow { height: 45px; }
.select2-container--default .select2-selection--single .select2-selection__rendered {
	border-radius: 0;
    padding: 6px 12px;
}
.select2-container--default .select2-selection--single {
    border: 1px solid #e9e9e9;
}
.woocommerce .woocommerce-customer-details address {
    padding: 0.7rem 0.9rem;
    background-color: #fff;
    border: 1px solid #e9e9e9;
	border-radius: 0;
	font-weight: 600;
}
p.woocommerce-notice.woocommerce-thankyou-order-received { margin: 0 0 20px; font-weight: 600; }
.woocommerce .woocommerce-MyAccount-content input.button { margin-top: 10px; }
.woocommerce-cart .wc-proceed-to-checkout { padding: 1rem 0 0; }
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button { padding: .750rem 1.2rem; margin-bottom: 0; box-shadow: none; }
.woocommerce-page #payment #place_order { float: right; height: 40px; }
.woocommerce form .form-row label, .woocommerce-page form .form-row label,
.wc_payment_method label, .woocommerce #review_form #respond p label { font-weight: 600; font-size: 0.938rem; }
.woocommerce form .form-row .required { text-decoration: none; }
.woocommerce form .form-row input.input-text { border-radius: 0; height: 45px; padding: 6px 12px; }
.select2-container .select2-choice { height: 46px; padding: 6px 12px; }
.woocommerce form .form-row .input-text, .woocommerce-page form .form-row .input-text { padding: 6px 12px; }
.woocommerce h3#order_review_heading { font-size: 1.500rem; margin: 25px 0; }
.woocommerce table.shop_table td { padding: 12px; font-weight: 600; }
.woocommerce table.shop_table tfoot th { font-weight: 600; }
.woocommerce .order_details { margin: 0 0 2rem; padding: 0; }
.woocommerce ul.order_details { padding: 0.5rem 0.9rem; background-color: #fff; border: 1px solid #e9e9e9; }
.woocommerce ul.order_details li { font-size: 0.875rem; }
.woocommerce ul.order_details li strong { font-size: 1.000rem; padding: 10px 0 0px; }
.woocommerce-error, .woocommerce-info, .woocommerce-message { padding: 0.675rem 3rem 0.675rem 1.250rem; }
.woocommerce-error::before, .woocommerce-info::before, .woocommerce-message::before { right: 1rem; }
.woocommerce .wc-bacs-bank-details-heading, .woocommerce h2, .woocommerce .title h3 { font-size: 1.125rem !important; }
.woocommerce .title h3 { font-weight: 500; }
.woocommerce nav.woocommerce-pagination { margin: 0 0 10px; }
.woocommerce nav.woocommerce-pagination ul, .woocommerce nav.woocommerce-pagination ul li { border: none; }
.woocommerce nav.woocommerce-pagination ul li a, .woocommerce nav.woocommerce-pagination ul li span {
    cursor: pointer;
    display: inline-block;
    font-family: 'Open Sans', Sans-serif;
    font-weight: 600;
    transition: all 0.3s ease 0s;
    font-size: 	1.125rem;
    border-radius: 0%;
    margin: 0 3px 10px;
    padding: 8px;
    vertical-align: baseline;
    white-space: nowrap;
    width: 37px;
    height: 37px;
}
.woocommerce-MyAccount-navigation ul li { list-style: none; padding: 0.8rem 0; font-weight: 600; }
.woocommerce-account .addresses .title .edit { font-weight: 600; }
.woocommerce-account .addresses .title .edit, .edit-account fieldset legend { border-bottom: none; padding: 20px 0 5px; margin: 0 0 20px; }
.woocommerce-MyAccount-navigation ul { padding: 0; }
.woocommerce-EditAccountForm input.woocommerce-Button { margin: 10px 0 0; padding: .900rem 1.5rem; border-radius: 0; transition: all 0.5s; }
.woocommerce form .form-row { padding: 0; margin: 0 0 15px; }
.woocommerce .woocommerce-Button { height: auto; margin: 10px 0 0; }
.woocommerce .page-title { margin: 0; }
.woocommerce div.product div.images div.thumbnails { margin-right: 0; }
.woocommerce .woocommerce-ordering { margin: 0 0 2rem; }
.woocommerce .woocommerce-ordering select {
    height: 44px;
    padding: 6px 12px;
    border-radius: 0;
    margin: 0;
    width: 100%;
}

.woocommerce-page .state_select a, .woocommerce-page .country_select a { border-radius: 0; color: #969dab !important; }

/*===================================================================================*/
/*  WOOCOMMERCE SIDEBAR WIDGETS
/*===================================================================================*/

.price_slider { margin-bottom: 1rem; }
.price_slider_amount { text-align: left; line-height: 2.4rem; font-size: 0.8751rem; }
.price_slider_amount .button { font-size: 1.15rem; float: right; }
.ui-slider { position: relative; text-align: right; }
.ui-slider .ui-slider-handle {
    position: absolute;
    z-index: 2;
    width: 0.9rem;
    height: 0.9rem;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    cursor: pointer;
    outline: none;
    top: -.3rem;
}
.ui-slider .ui-slider-handle:last-child { margin-right: -1rem; }
.ui-slider .ui-slider-range {
    position: absolute;
    z-index: 1;
    font-size:.7rem;
    display: block;
    border: 0;
    -webkit-border-radius: 1rem;
    -moz-border-radius: 1rem;
    border-radius: 1rem;
}
.price_slider_wrapper .ui-widget-content {
    -webkit-border-radius: 1rem;
    -moz-border-radius: 1rem;
    border-radius: 1rem;
}
.ui-slider-horizontal { height:.5rem; }
.ui-slider-horizontal .ui-slider-range-min { right: -1px; }
.ui-slider-horizontal .ui-slider-range-max { left: -1px; }
.woocommerce li.cat-item { padding: 5px 0; }
.woocommerce .woocommerce-product-search, .woocommerce .price_slider_wrapper { padding: 30px 25px; }
.woocommerce .widget_shopping_cart .total, .woocommerce.widget_shopping_cart .total { padding: 30px 25px; }
.woocommerce.widget_shopping_cart .buttons { padding: 30px 25px; }
.woocommerce .dropdown_product_cat { margin:30px 25px; }
.woocommerce-product-search input[type="search"] {
    font-weight: 500;
    margin: 0px 0px 15px 0px;
    border: 1px solid #e9e9e9;
    transition: border-color 0.15s ease-in-out 0s, box-shadow 0.15s ease-in-out 0s;
}
.woocommerce-product-search input[type="submit"] {
	border: none;
    border-radius: 0px;
    display: inline-block;
    font-weight: 500;
    font-size: 1.125rem;
    font-weight: normal;
    margin-bottom: 10px;
    margin-left: 0px;
	margin-top: 0;
    padding: 9px 25px;
    text-align: center;
    vertical-align: middle;
    white-space: nowrap;
}
.sidebar-widget .widget-title { font-size: 	1.500rem; padding-bottom: 11px; display: inline-block; margin: 0 0 20px; }
.woocommerce .sidebar-widget { margin: 0 0 50px; }
.woocommerce .widget_layered_nav ul li, .woocommerce .widget_rating_filter ul li { padding: 12px 0 !important; border-bottom: 1px dotted #c5d1dc; }
.woocommerce .widget_layered_nav ul li:last-child, .woocommerce .widget_rating_filter ul li:last-child { padding-bottom: 0; border-bottom: 0 none; }
.woocommerce .sidebar-widget ul { padding: 0; list-style: none; }
.woocommerce ul.product_list_widget li a:before, .product_list_widget li a:before { display:none; }
.product_list_widget a { margin: 0 0 5px; }
.woocommerce ul.cart_list li dl, .woocommerce ul.product_list_widget li dl{padding-right:0;border-right:none; }
.woocommerce ul.cart_list li dl dt, .woocommerce ul.product_list_widget li dl dt{ font-size: 1.000rem; }
.woocommerce ul.cart_list li { margin: 0 0 15px; }
.woocommerce ul.product_list_widget li, .product_list_widget li { padding: 15px 0; margin-bottom: 0px; border-bottom: 1px dotted #c5d1dc; }
.woocommerce ul.product_list_widget li:last-child, .product_list_widget li:last-child { padding-bottom: 0; border-bottom: 0 none; }
.sidebar .product_list_widget li:first-child { padding-top: 0px !important; }
.sidebar-widget ul.product_list_widget { padding: 0; }
.product_list_widget li { list-style: none; }
.woocommerce ul.cart_list li img,
.woocommerce ul.product_list_widget li img,
.woocommerce-page ul.product_list_widget li img { width: 60px; float: right; margin-right: 0; margin-left: 15px; padding-right: 0px; }
.woocommerce .widget_shopping_cart .cart_list li a.remove,
.woocommerce.widget_shopping_cart .cart_list li a.remove { position: absolute; top: 0; right: 0; }
.woocommerce .widget_shopping_cart .cart_list li,
.woocommerce.widget_shopping_cart .cart_list li { padding-right: 2rem; position: relative; padding-top: 0; }
.woocommerce .order_details { padding: 0; }
.blog-post-title-wrapper h2, .title h3 { font-weight: 300; }
.woocommerce-account .addresses .title .edit, .edit-account fieldset legend { padding: 20px 0 5px; margin: 0 0 20px; }
.woocommerce-cart .cart-collaterals .cart_totals tr th, .woocommerce-cart .cart-collaterals .cart_totals tr td { border-top: none; }
.form-row input[type="submit"] { height: 46px; }
.price_label { font-weight: 600; font-size: 1.00rem; }

.woocommerce .widget_shopping_cart .cart_list li, .woocommerce.widget_shopping_cart .cart_list li { margin-bottom: 15px; }
.woocommerce form.login, .woocommerce form.register { padding: 0; border: none;  }
ul.product-categories { margin-right: 25px !important; }
ul.product-categories ul { padding-top: 0 !important; padding-bottom: 0 !important; }
.woocommerce-product-search input[type="submit"], button[type="submit"], .widget button[type="submit"] {
	color: #ffffff;
	border: 0 none;
    border-radius: 0px;
    display: inline-block;
	font-size: 0.875rem;
	height: 45px;
    margin: 0;
    padding: 12px 22px;
    text-align: center;
    transition: all 0.4s ease 0s;
}
.woocommerce-product-search input[type="submit"],
button[type="submit"], .widget button[type="submit"] {
	background-color: #ce1b28;
}

/*===================================================================================*/
/*	WOOCOMMERCE PRODUCT
/*===================================================================================*/

.product_container { padding: 0.4em 0.4em 1.5em; }

.five-column .col-md-2:nth-child(5n+1) { clear: right; }

/*===================================================================================*/
/*  WOOCOMMERCE CSS
/*===================================================================================*/
.woocommerce .woocommerce-result-count { margin: 1rem 0 1rem; }
.woocommerce .products ul, .woocommerce ul.products { margin: 0; }
.woocommerce ul.products li.product h3 { text-align: center; margin: 0rem 0 1rem; padding: 0; font-weight: 700; }
.woocommerce .products .star-rating { margin: 0 auto .5rem; }
.woocommerce .price { text-align: center; }
.woocommerce div.product p.price, .woocommerce div.product span.price { font-size: 1.25rem; }
.woocommerce ul.products li.product .price,
.woocommerce ul.products li.product .price del { font-size: 1.1rem; font-weight: 600; }
.woocommerce ul.products li.product .price del { display: inline-block; }
.woocommerce ul.products li.product .price ins, .price ins { font-weight: 600; color: #64646d; }
.woocommerce div.product p.price { text-align: right; font-weight: 600; }
.woocommerce ul.products li.product,
.woocommerce-page ul.products li.product { transition: all 0.6s; text-align: center; padding: 0.4rem 0.4rem 1.5rem; margin-bottom: 2rem; }
.woocommerce-page ul.products li.product:hover { box-shadow: 0 14px 25px 0 rgba(0,0,0,0.2); }
.woocommerce ul.products li.product .onsale, .woocommerce span.onsale {
    left: inherit;
    min-width: auto;
    min-height: auto;
    color: #fff;
    border-radius: 0;
    font-size: 0.750rem;
    line-height: 0.700rem;
    padding: .200rem .350rem .300rem;
    margin: 0;
    position: absolute;
    right: 10px;
    top: 10px;
    transition: all 0.5s;
}
.woocommerce ul.products li.product .button, .woocommerce a.added_to_cart {
    box-shadow: none;
    font-weight: 700;
    line-height: 1.3;
    border-radius: 0px;
    padding: .600rem 0.7rem;
    transition: all 0.5s;
    margin-top: 0.7rem;
    height: 38px;
}
.woocommerce a.button { border-radius: 0px; box-shadow: none; }
.woocommerce table.my_account_orders .order-actions .button { margin: 0 2px; }
.woocommerce table.my_account_orders .order-actions .button:last-child { margin-top: 4px; }
.woocommerce div.product form.cart .button, .woocommerce a.button, .woocommerce a.button:hover { padding: .700rem 1.2rem; }
.woocommerce .posted_in a, .woocommerce-product-rating a, .woocommerce .tagged_as a { transition: all 0.5s; font-weight: 600; }
.woocommerce div.product form.cart { margin-top: 2rem; padding: 0; }
.woocommerce div.product form.cart .variations { padding: 2rem 0; margin: 0 0 2rem; }
.woocommerce .variations td.label { padding: 0; font-size:  0.938rem; }
.woocommerce div.product form.cart .variations select { padding: 6px 12px; height: 45px; border-radius: 2px; font-size: 0.875rem; border: 1px solid #e9e9e9; }
.woocommerce div.product form.cart .variations tr { display: block; padding: 0; }
.woocommerce div.product form.cart .variations td { display: list-item; list-style: none; text-align: right; line-height: 1.2rem; padding: 0rem; }
.woocommerce div.product form.cart .variations td.label label { font-family: 'Open Sans', Sans-serif; margin-bottom: 15px; }
.woocommerce .woocommerce-variation-price { margin: 0 0 1rem; }
.woocommerce-variation-price .woocommerce-Price-amount { font-weight: 600; }
.woocommerce-tabs { padding: 2rem 0 0; }
.woocommerce div.product #reviews .comment img,
.woocommerce-page div.product #reviews .comment img { border-radius: 100%; height: 70px; margin: 2px 0 20px; width: 70px; float: right; }
.woocommerce #reviews #comments ol.commentlist { padding: 0; }
.woocommerce #reviews #comments ol.commentlist li .comment-text { margin: 0 90px 0 0; }
#review_form_wrapper { margin: 3rem 0 2rem; }
.woocommerce #reviews #comments ol.commentlist li .meta strong { font-size: 1.000rem; }
.woocommerce #reviews #comments ol.commentlist li .meta time { font-size: 1.000rem; }
.woocommerce #reviews h3 { margin: 0 0 1rem; }
.woocommerce div.product .woocommerce-tabs .panel { box-shadow: none; padding: 1rem 1rem 1rem; border-radius: 0; }
.woocommerce-error li, .woocommerce-info li, .woocommerce-message li { padding: 0; }
.woocommerce-Tabs-panel h2, .woocommerce .related h2,
.woocommerce .cart-collaterals .cart_totals h2, .woocommerce-page .cart-collaterals .cart_totals h2 { font-size: 1.500rem; }
.woocommerce .related h2 { margin: 0 0 20px; }
.woocommerce table.shop_table { border-radius: 0; margin: 0 0 40px -1px; padding: 0; }
.woocommerce table.shop_table th { border: none; font-size: 1.000rem; padding: 12px; font-weight: 600; }
.woocommerce table.shop_table td { border-right: none; border-left: none; border-bottom: none; }
.woocommerce-cart table.cart td { font-weight: 600; padding: 15px 12px; }
.woocommerce-cart table.cart td a { font-weight: 600; transition: all 0.3s; }
.woocommerce-cart .cart-collaterals .cart_totals table td { vertical-align: middle; }
.woocommerce-cart .cart-collaterals .cart_totals tr th, .woocommerce table.shop_table td a { font-weight: 600; }
#add_payment_method table.cart img, .woocommerce-cart table.cart img, .woocommerce-checkout table.cart img { width: 70px; }
.woocommerce .quantity .qty { width: 3.5rem; text-align: right; height: 44px; padding: .500rem 0.7rem; border-radius: 0; }
.woocommerce td.product-name dl.variation { margin: .35rem 0 0; }
.woocommerce td.product-name dl.variation dt, .woocommerce td.product-name dl.variation dd, .woocommerce td.product-name dl.variation dd p { line-height: 20px; }
.woocommerce-cart table.cart td.actions .coupon .input-text { width: 200px; padding: 6px 12px; border-radius: 0; height: 44px; }
.woocommerce .cart input.button, .woocommerce input.button.alt, .woocommerce button.button, .woocommerce #respond input#submit {
    border-radius: 1px;
    padding: .600rem 0.7rem;
    transition: all 0.5s;
    height: 44px;
}
.woocommerce-page .cart input.button:hover,
.woocommerce .cart input.button:focus,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:focus,
.woocommerce input.button.alt:hover,
.woocommerce input.button.alt:focus,
.woocommerce input.button:hover,
.woocommerce input.button:focus,
.woocommerce button.button:hover,
.woocommerce button.button:focus,
.woocommerce #respond input#submit:hover,
.woocommerce #respond input#submit:focus {
    box-shadow: none;
}
.woocommerce div.product .woocommerce-tabs ul.tabs::before { border-bottom: 1px solid #e9e9e9; }
.woocommerce div.product .woocommerce-tabs ul.tabs li::before {
    -webkit-box-shadow: -2px 2px 0 #e9e9e9;
    box-shadow: -2px 2px 0 #e9e9e9;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li,
.woocommerce div.product .woocommerce-tabs ul.tabs li::after,
.woocommerce div.product .woocommerce-tabs ul.tabs li::before {
    border: 1px solid #e9e9e9;
}
.select2-container .select2-selection--single,
.select2-container--default .select2-selection--single .select2-selection__arrow { height: 45px; }
.select2-container--default .select2-selection--single .select2-selection__rendered {
    border-radius: 0;
    padding: 6px 12px;
}
.select2-container--default .select2-selection--single {
    border: 1px solid #e9e9e9;
}
.woocommerce .woocommerce-customer-details address {
    padding: 0.7rem 0.9rem;
    background-color: #fff;
    border: 1px solid #e9e9e9;
    border-radius: 0;
    font-weight: 600;
}
p.woocommerce-notice.woocommerce-thankyou-order-received { margin: 0 0 20px; font-weight: 600; }
.woocommerce .woocommerce-MyAccount-content input.button { margin-top: 10px; }
.woocommerce-cart .wc-proceed-to-checkout { padding: 1rem 0 0; }
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button { padding: .750rem 1.2rem; margin-bottom: 0; box-shadow: none; }
.woocommerce-page #payment #place_order { float: right; height: 40px; }
.woocommerce form .form-row label, .woocommerce-page form .form-row label,
.wc_payment_method label, .woocommerce #review_form #respond p label { font-weight: 600; font-size: 0.938rem; }
.woocommerce form .form-row .required { text-decoration: none; }
.woocommerce form .form-row input.input-text { border-radius: 0; height: 45px; padding: 6px 12px; }
.select2-container .select2-choice { height: 46px; padding: 6px 12px; }
.woocommerce form .form-row .input-text, .woocommerce-page form .form-row .input-text { padding: 6px 12px; }
.woocommerce h3#order_review_heading { font-size: 1.500rem; margin: 25px 0; }
.woocommerce table.shop_table td { padding: 12px; font-weight: 600; }
.woocommerce table.shop_table tfoot th { font-weight: 600; }
.woocommerce .order_details { margin: 0 0 2rem; padding: 0; }
.woocommerce ul.order_details { padding: 0.5rem 0.9rem; background-color: #fff; border: 1px solid #e9e9e9; }
.woocommerce ul.order_details li { font-size: 0.875rem; }
.woocommerce ul.order_details li strong { font-size: 1.000rem; padding: 10px 0 0px; }
.woocommerce-error, .woocommerce-info, .woocommerce-message { padding: 0.675rem 3rem 0.675rem 1.250rem; }
.woocommerce-error::before, .woocommerce-info::before, .woocommerce-message::before { right: 1rem; }
.woocommerce .wc-bacs-bank-details-heading, .woocommerce h2, .woocommerce .title h3 { font-size: 1.125rem !important; }
.woocommerce .title h3 { font-weight: 500; }
.woocommerce nav.woocommerce-pagination { margin: 0 0 10px; }
.woocommerce nav.woocommerce-pagination ul, .woocommerce nav.woocommerce-pagination ul li { border: none; }
.woocommerce nav.woocommerce-pagination ul li a, .woocommerce nav.woocommerce-pagination ul li span {
    cursor: pointer;
    display: inline-block;
    font-family: 'Open Sans', Sans-serif;
    font-weight: 600;
    transition: all 0.3s ease 0s;
    font-size:  1.125rem;
    border-radius: 0%;
    margin: 0 3px 10px;
    padding: 8px;
    vertical-align: baseline;
    white-space: nowrap;
    width: 37px;
    height: 37px;
}
.woocommerce-MyAccount-navigation ul li { list-style: none; padding: 0.8rem 0; font-weight: 600; }
.woocommerce-account .addresses .title .edit { font-weight: 600; }
.woocommerce-account .addresses .title .edit, .edit-account fieldset legend { border-bottom: none; padding: 20px 0 5px; margin: 0 0 20px; }
.woocommerce-MyAccount-navigation ul { padding: 0; }
.woocommerce-EditAccountForm input.woocommerce-Button { margin: 10px 0 0; padding: .900rem 1.5rem; border-radius: 0; transition: all 0.5s; }
.woocommerce form .form-row { padding: 0; margin: 0 0 15px; }
.woocommerce .woocommerce-Button { height: auto; margin: 10px 0 0; }
.woocommerce .page-title { margin: 0; }
.woocommerce div.product div.images div.thumbnails { margin-right: 0; }
.woocommerce .woocommerce-ordering { margin: 0 0 2rem; }
.woocommerce .woocommerce-ordering select {
    height: 44px;
    padding: 6px 12px;
    border-radius: 0;
    margin: 0;
    width: 100%;
}


.woocommerce-page .state_select a, .woocommerce-page .country_select a { border-radius: 0; color: #969dab !important; }

/* Text meant only for screen readers. */
.screen-reader-text {
	border: 0;
    clip: rect(1px, 1px, 1px, 1px);
    -webkit-clip-path: inset(50%);
    clip-path: inset(50%);
    height: 1px;
    margin: -1px;
    overflow: hidden;
    padding: 0;
    position: absolute;
    width: 1px;
    word-wrap: normal !important;
}
.screen-reader-text:focus {
	background-color: #f1f1f1;
	border-radius: 3px;
	box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.6);
	clip: auto !important;
	color: #21759b;
	display: block;
	font-size: 14px;
	font-size: 0.875rem;
	font-weight: bold;
	height: auto;
	right: 5px;
	line-height: normal;
	padding: 15px 23px 14px;
	text-decoration: none;
	top: 5px;
	width: auto;
	z-index: 100000; /* Above WP toolbar. */
}

.no-js .some-element .screen-reader-text {
    position: static;
    -webkit-clip-path: none;
    clip-path: none;
    width: auto;
    height: auto;
    margin: 0;
}


.widget-address {
    margin-bottom: 0;
    margin-top: 25px !important;
    padding-bottom: 0;
}

.widget-address .addr-icon {
    color: #9595a0;
    float: right;
    margin-right: 0;
    margin-left: 15px;
    transition: all 0.4s ease 0s;
}

.widget-address .addr-icon i {
    padding-right: 1px;
    font-size: 1.875rem;
}

.widget-address address {
    display: block;
    font-weight: 600;
    font-size: 1.250rem;
    margin-bottom: 10px;
    margin-top: 0;
    word-wrap: break-word;
    font-style: normal;
}

.widget-address address > abbr {
    border-bottom: 1px dotted #6e6d75;
    color: #7f7f87;
    line-height: 25px;
    font-weight: 500;
    font-size: 0.875rem;
    margin: 0;
    padding: 0;
}

/*===================================================================================*/
/*	WOOCOMMERCE SINGLE PRODUCT CSS
/*===================================================================================*/

.single-product .pswp__button { background-color: transparent; }
.single-product div.product { position: relative; overflow: hidden; }
.single-product div.product:after,.single-product div.product:before {
  content: '';
  display: table;
}
.single-product div.product:after {
  clear: both;
}
.single-product div.product .images,.single-product div.product .summary,.single-product div.product .woocommerce-product-gallery {
  margin-bottom: 2.617924em;
  margin-top: 0;
}
.single-product div.product .woocommerce-product-gallery {
  position: relative;
}
.single-product div.product .woocommerce-product-gallery .zoomImg {
  background-color: #fff;
}
.single-product div.product .woocommerce-product-gallery .woocommerce-product-gallery__trigger {
  position: absolute;
  top: .875em;
  left: .875em;
  display: block;
  height: 2em;
  width: 2em;
  border-radius: 3px;
  z-index: 99;
  text-align: center;
}
.single-product div.product .woocommerce-product-gallery img {
  margin: 0;
}
.single-product div.product .woocommerce-product-gallery .flex-viewport {
  margin-bottom: 1.618em;
}
.single-product div.product .woocommerce-product-gallery .flex-control-thumbs {
  margin: 0;
  padding: 0;
}
.single-product div.product .woocommerce-product-gallery .flex-control-thumbs:after,
.single-product div.product .woocommerce-product-gallery .flex-control-thumbs:before {
  content: '';
  display: table;
}
.single-product div.product .woocommerce-product-gallery .flex-control-thumbs:after {
  clear: both;
}
.single-product div.product .woocommerce-product-gallery .flex-control-thumbs li {
  list-style: none;
  margin-bottom: 1.618em !important;
  cursor: pointer;
}
.single-product div.product .woocommerce-product-gallery .flex-control-thumbs li img {
  opacity: 1 !important;
  -webkit-transition: all,ease,.2s;
  transition: all,ease,.2s;
}
.single-product div.product .woocommerce-product-gallery .flex-control-thumbs li img.flex-active {
  opacity: 1;
}
.single-product div.product .woocommerce-product-gallery .flex-control-thumbs li:hover img {
  opacity: 1;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-2 .flex-control-thumbs li {
  width: 42.8571428571%;
  float: right;
  margin-left: 14.2857142857%;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-2 .flex-control-thumbs li:nth-child(2n) {
  margin-left: 0;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-2 .flex-control-thumbs li:nth-child(2n+1) {
  clear: both;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-3 .flex-control-thumbs li {
  width: 23.8095238%;
  float: right;
  margin-left: 14.2857142857%;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-3 .flex-control-thumbs li:nth-child(3n) {
  margin-left: 0;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-3 .flex-control-thumbs li:nth-child(3n+1) {
  clear: both;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-4 .flex-control-thumbs li {
  /* width: 14.2857142857%; */
  /* float: left; */
  /* margin-right: 14.2857142857%; */
    width: 22%;
    float: right;
    margin-left: 4%;

}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-4 .flex-control-thumbs li:nth-child(4n) {
  margin-left: 0;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-4 .flex-control-thumbs li:nth-child(4n+1) {
  clear: both;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-5 .flex-control-thumbs li {
  width: 8.5714285714%;
  float: right;
  margin-left: 14.2857142857%;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-5 .flex-control-thumbs li:nth-child(5n) {
  margin-left: 0;
}
.single-product div.product .woocommerce-product-gallery.woocommerce-product-gallery--columns-5 .flex-control-thumbs li:nth-child(5n+1) {
  clear: both;
}

.pswp__caption__center {
   text-align: center;
}

/* Woocommerce page layout CSS */

.woocommerce .related{
	clear:both;
}

/*===================================================================================*/
/*	 Skip to content
/*===================================================================================*/
/* Text meant only for screen readers. */
.spicepress-screen-reader {
	clip: rect(1px, 1px, 1px, 1px);
	position: absolute !important;
	height: 1px;
	width: 1px;
	overflow: hidden;
	word-wrap: normal !important;
	/* Many screen reader and browser combinations announce broken words as they would appear visually. */
}

.spicepress-screen-reader:focus {
	background-color: #f1f1f1;
	border-radius: 3px;
	box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.6);
	clip: auto !important;
	color: #21759b;
	display: block;
	font-size: 13px;
	font-weight: 700;
	height: auto;
	right: 5px;
	line-height: normal;
	padding: 15px 23px 14px;
	text-decoration: none;
	top: 5px;
	width: auto;
	z-index: 100000;
	/* Above WP toolbar. */
}

/* Do not show the outline on the skip link target. */
#content[tabindex="-1"]:focus {
	outline: 0;
}

/*===================================================================================*/
/*	CONTACT FORM 7 SECTION
/*===================================================================================*/

.wpcf7-form {
	text-align: right;
}
.wpcf7-form input, .wpcf7-form textarea {
	max-width: 100%;
	direction: rtl;
}
@media (min-width: 1100px){
	.navbar-custom .dropdown-toggle:after {
/*    position: absolute;
    display: block;
    right: 0px;
    top: 50%;
    margin-top: -10px;
    font-family: FontAwesome;
    font-size: 15px;
    line-height: 1.2;
    content: "\f107";
    text-rendering: auto;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;*/
}
}
@media (min-width: 1100px) {
.navbar-nav li button { display: none;}
}

@media (max-width: 1100px){
	 .navbar-custom .nav li.dropdown a{ display: inline-block;}}


.navbar-custom .navbar-nav .open .dropdown-menu .dropdown-header, .navbar-custom .navbar-nav .open .dropdown-menu > li > button {
    margin-bottom: 0px !important;
    margin-top: 0px !important;
   }
}
.reply a:focus {color: #ffffff;}
.home-news .post-thumbnail a,.blog-section .post-thumbnail a{
    display: block;}

@media (min-width: 1100px){
.rtl .navbar-custom .navbar-nav > li {
    float: right;
}}
input[type="reset"] { background-color: #21202e; }
form.search-form input.search-submit,
input[type="submit"], input[type="reset"],
.woocommerce-product-search input[type="submit"], .home-blog-btn {
	color: #ffffff;
	border: 0 none;
    border-radius: 0px;
    display: inline-block;
	font-size: 0.875rem;
	height: 45px;
    margin: 0;
    padding: 12px 22px;
    text-align: center;
    transition: all 0.4s ease 0s;
}
.home-blog-btn
{
	margin-top: 20px;
}
.home-blog-btn
{
	color: #ffffff !important;
}
.rtl .fa-angle-double-left:before {
    content: "\f101";
}
.rtl .fa-angle-double-right:before {
    content: "\f100";
}
.rtl .blog-author .pull-left {
    float: right !important;
}
.rtl .entry-meta a {display: inline;}
input:focus,textarea:focus,.navbar-toggle:focus,.open > a:focus,.dropdown-toggle:focus,.navbar-custom .dropdown-menu > .active > a:focus,.navbar-custom .navbar-nav .open .dropdown-menu > .active > a:focus  {
    outline: thin dotted;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
}
.blog-author,.comment,.comment-form-section,.comment-section,.service-section .post,.home-news .post,.site-info{visibility:visible !important; }
/*@media (min-width: 1100px){
.navbar-custom .dropdown-menu .dropdown-toggle:after {
    content: "\f105";
}}*/
.blog-section .entry-content a, .textwidget a, .comment-detail a {
	text-decoration: underline;
}
.comment-detail .edit-link a, .comment-detail .reply a {
	text-decoration: none;
}
.wpcf7-form label {
	width: 100%;
}
.woocommerce.woocommerce-page .widget_categories li:before{
    position: absolute;
    right: 0;
    top: 5px;
    content: '\f00c';
    font-family: 'FontAwesome';
}
.woocommerce.woocommerce-page .footer-sidebar .widget_categories a{
    padding: 0px 25px 12px 0px;
}
/*===================================================================================*/
/*	24.0 Widget Classes
/*===================================================================================*/
.sidebar .wp-block-search .wp-block-search__label,.sidebar .widget.widget_block h1,.sidebar .widget.widget_block h2,.sidebar .widget.widget_block h3,.sidebar .widget.widget_block h4,.sidebar .widget.widget_block h5,.sidebar .widget.widget_block h6, .sidebar .widget.widget_block .wc-block-product-search__label{
   background-color: #21202e;
    width: 100%;
    margin-bottom: 0px;
    margin-top: 0px;
    padding: 16px 20px;
    display: block;
    text-align: right;
	 border-right: 5px solid #ce1b28;
  color:#fff;
	 font-weight:600;
    margin: 0;
    word-wrap: break-word;
}
.sidebar .wp-block-search .wp-block-search__label,.sidebar .widget.widget_block h3{font-size:1.250rem;}
.wp-block-search .wp-block-search__inside-wrapper{
	padding:30px 25px;
	display:block;
}
.wp-block-search .wp-block-search__input {
    margin-bottom: 20px;
}
.widget .wp-block-search button[type="submit"] {font-weight:700}
.widget li:before {
    position: absolute;
    content: '\f00c';
    font-family: 'FontAwesome';
    color: #ce1b28;
    right:0;
}
.sidebar .widget.widget_block li, .footer-sidebar .widget.widget_block li {
	   list-style-type:none;
    font-weight: 500;
    border-bottom: 1px dotted #c5d1dc;
    margin: 0 0 12px;
		padding: 0 25px 12px 0;
    position: relative;
}
.wp-block-tag-cloud a{
	background-color: #f9f9f9;
    border: 1px solid #e9e9e9;
    color: #64646d;
    cursor: pointer;
    display: inline-block;
    font-size: 0.938rem !important;
    margin: 0 5px 10px 0;
    padding: 6px 14px;
    transition: all 0.3s ease 0s;
    vertical-align: baseline;
    white-space: nowrap;
}
.wp-block-tag-cloud {margin: 0;
	padding: 30px 25px;}
.wp-block-tag-cloud a:hover {
    background-color: #ce1b28;
    border: 1px solid #ce1b28;
	  color:#fff !important;
}
.widget .wp-block-gallery li{padding:0;}
 .widget .wp-block-gallery li:before,.widget .custom-social-icons li:before{
	display:none;
}
.widget li:first-child,.footer-sidebar .widget li:first-child{
	padding-top:0;
}
.widget li:last-child,.footer-sidebar .widget li:last-child{
  padding-bottom: 0px;
  border-bottom: none;
}
.footer-sidebar .wp-block-page-list a{
    color: #9595a0;
}
.footer-sidebar .wp-block-page-list a:hover{
    color: #ce1b28;
}
.footer-sidebar .widget li{
border-bottom:1px dotted #403f4e;
}
.footer-sidebar .wp-block-search__label{
	color: #ffffff;
    font-weight: 400;
    margin: 0;
    padding-bottom: 0px;
    word-wrap: break-word;
}
 .footer-sidebar .wp-block-search__label:after,.footer-sidebar .widget_block h1:after, .footer-sidebar .widget_block h2:after,.footer-sidebar .widget_block h3:after,.footer-sidebar .widget_block h4:after,.footer-sidebar .widget_block h5:after,.footer-sidebar .widget_block h6:after{
   	content: "";
    display: block;
    height: 4px;
    margin-top: 13px;
    position: absolute;
    bottom: auto;
    right: 0;
    width: 30px;
    background-color: #ce1b28;
}
.footer-sidebar .wp-block-search__label,.footer-sidebar .widget_block h1,.footer-sidebar .widget_block h2,.footer-sidebar .widget_block h3,.footer-sidebar .widget_block h4,.footer-sidebar .widget_block h5,.footer-sidebar .widget_block h6{
    border-bottom: 1px solid #363544;
    width: 100%;
    padding: 0 0 15px;
    margin: 0 0 40px;
    display: block;
    text-align: right;
    font-weight: 400;
}
.footer-sidebar .wp-block-search .wp-block-search__label,.footer-sidebar .widget_block h3{font-size: 1.5rem;}
.sidebar .widget ol{
      margin: 0;
    padding: 30px 25px;
}
.widget .wp-block-latest-comments__comment{line-height: 1.6;}
.widget .wp-block-social-links li:before{display: none;}
.wp-block-social-links .wp-social-link.wp-social-link.wp-social-link {
    padding: 0;
}
.wp-block-social-links .wp-block-social-link .wp-block-social-link-anchor, .wp-block-social-links .wp-block-social-link .wp-block-social-link-anchor:active, .wp-block-social-links .wp-block-social-link .wp-block-social-link-anchor:hover, .wp-block-social-links .wp-block-social-link .wp-block-social-link-anchor:visited, .wp-block-social-links .wp-block-social-link .wp-block-social-link-anchor svg {
    color: currentColor !important;
    fill: currentColor;
}
}
.sidebar .widget .widget{box-shadow:none;margin: 0;}
.sidebar .widget.widget_block p{
    margin: 0;
    padding: 30px 25px;
}
.footer-sidebar .wp-block-social-links{margin-left: 5px;}
.footer-sidebar ol.wp-block-latest-comments {
    padding: 0;
}
.footer-sidebar .wp-block-tag-cloud {
    padding: 0;
}
.widget .wp-block-calendar a {
    text-decoration: none;
}
.footer-sidebar .widget.widget_block ul,.footer-sidebar .widget.widget_block ol {
    padding: 0;
}
.footer-sidebar .widget.widget_nav_menu ul .sub-menu { padding: 30px 25px; }
.sidebar .widget.widget_block li a::before, .footer-sidebar .widget.widget_block li a::before {
	display: none;
}
.sidebar .wp-block-calendar {
	padding: 30px 25px;
}
.widget.widget_block .wc-block-product-search__fields {
		padding: 30px 25px;
    display: block;
}
.footer-sidebar .wp-block-search .wp-block-search__inside-wrapper {
    padding: 30px 0;
    display: block;
}
.widget.widget_block p:not(.wp-block-tag-cloud) a, .footer-sidebar .widget.widget_block p:not(.wp-block-tag-cloud) a { text-decoration: underline; }
.sidebar .widget.widget_block .wp-block-contact-form-7-contact-form-selector p {
	padding: 0;
}
.sidebar .widget.widget_block .wp-block-contact-form-7-contact-form-selector .wpcf7-form .wpcf7-submit{
	margin: 25px;
}
.widget_block .wp-block-latest-posts .blog-btn a, .widget_block .wp-block-latest-posts .blog-btn a:hover{
	color: #fff !important;
}
/* css for breadcrumbs */
.sp-breadcrumb {
    color: #ffffff;
}
.sp-breadcrumb a {
    color: #ffffff;
}
.sp-breadcrumb .last {
    color: #ffffff;
}
.rank-math-breadcrumb .separator {
    color: #ffffff;
}

/*Post Navigation */
.post .nav-links{display: flex;}
.post .nav-previous,.post .nav-next {display: flex;flex: auto;flex-basis: 50%;}
.post .nav-subtitle {display: block;font-size: 14px;font-weight: 600;margin-bottom: 10px}
.post .nav-next { flex-direction: row-reverse;}
.post .nav-subtitle i{letter-spacing: 3px;}
.post .nav-title{font-size: 16px;font-weight:400;color:#0f0f16;}
.post .edit-link a{padding-left: 5px;}
.post .edit-link{margin-top: 15px;display: block;}
 @media (max-width:550px){
   .post .nav-links{display: block;} 
   .post .nav-previous,.post .nav-next{max-width: 100%;flex-basis: 100%;display: block;}
   .post .nav-previous{margin-bottom: 15px;}
   .post .nav-next a{text-align: left;}
}

.navbar-custom .navbar-nav li > a,.service-section a {text-decoration: none;}
.testmonial-area .media-body {display: table-cell;vertical-align: top;}
@media (min-width: 1200px) {.container {width: 1170px;}}
.testimonial-section .item{padding: 0;}
body .home-news .post .entry-content .more-link{margin-top: 15px;}
a{text-decoration: none;}
.navbar-custom {padding: 0;}
.home-news .more-link::after, .blog-section .more-link::after{margin-top: 2px;}
.navbar-custom .navbar-nav li > a {display: block;}
.navbar-custom .navbar-nav .dropdown-menu li > a {line-height: 1.3;}
.dropdown-menu .dropdown-toggle::after{display: none;}

@media (max-width: 500px) {
	body .navbar-expand-lg .navbar-toggler {float: none !important;margin: 10px auto 25px;}
	.navbar-custom .navbar-brand {display: unset;}
}
.media{overflow: hidden;}
blockquote {padding: 10px;}
.navbar-custom li.open .dropdown-menu.search-panel{display: block;}
.navbar-left{float: right !important;}
.navbar-right{float: left !important;}
@media (max-width: 500px) {body .navbar-expand-lg.right .navbar-toggler{margin: 30px auto 10px;}}
.blog-list-layout .media-body{display: table-cell;vertical-align: top;}
body .dropdown-toggle::after {margin-right: 0.255em;margin-left: 0;}
body .page-breadcrumb {float: left;}
body .page-title h1{float: right;}
@media (max-width: 767px){body .page-breadcrumb,body .page-title h1 {float: unset;}}
body.rtl .float-start {float: right !important;}